
// This Source Code Form is subject to the terms of the Mozilla Public
// License, version 2.0. If a copy of the MPL was not distributed with this
// file, You can obtain one at http://mozilla.org/MPL/2.0/.

#include <stdlib.h>

#define MAX_TEXTS 7
#define MAX_NAMES 4

struct t_slack_emoji_by_name {
    const char *name;
    const char *unicode;
    const char *text_to;
    const char *text_from[MAX_TEXTS];
};

struct t_slack_emoji_by_text {
    const char *text;
    const char *unicode;
    const char *name_to;
    const char *name_from[MAX_NAMES];
};

static struct t_slack_emoji_by_name slack_emoji_by_name[] =
{ { "+1", "\u1f44D", NULL, {NULL} }
, { "-1", "\u1f44E", NULL, {NULL} }
, { "100", "\u1f4aF", NULL, {NULL} }
, { "1234", "\u1f522", NULL, {NULL} }
, { "8ball", "\u1f3b1", NULL, {NULL} }
, { "a", "\u1f170\ufe0f", NULL, {NULL} }
, { "ab", "\u1f18E", NULL, {NULL} }
, { "abc", "\u1f524", NULL, {NULL} }
, { "abcd", "\u1f521", NULL, {NULL} }
, { "accept", "\u1f251", NULL, {NULL} }
, { "admission_tickets", "\u1f39F\ufe0f", NULL, {NULL} }
, { "adult", "\u1f9d1", NULL, {NULL} }
, { "aerial_tramway", "\u1f6a1", NULL, {NULL} }
, { "airplane", "\u2708\ufe0f", NULL, {NULL} }
, { "airplane_arriving", "\u1f6eC", NULL, {NULL} }
, { "airplane_departure", "\u1f6eB", NULL, {NULL} }
, { "alarm_clock", "\u23f0", NULL, {NULL} }
, { "alembic", "\u2697\ufe0f", NULL, {NULL} }
, { "alien", "\u1f47D", NULL, {NULL} }
, { "ambulance", "\u1f691", NULL, {NULL} }
, { "amphora", "\u1f3fA", NULL, {NULL} }
, { "anchor", "\u2693", NULL, {NULL} }
, { "angel", "\u1f47C", NULL, {NULL} }
, { "anger", "\u1f4a2", NULL, {NULL} }
, { "angry", "\u1f620", NULL, {">:(", ">:-(", NULL} }
, { "anguished", "\u1f627", NULL, {"D:", NULL} }
, { "ant", "\u1f41C", NULL, {NULL} }
, { "apple", "\u1f34E", NULL, {NULL} }
, { "aquarius", "\u2652", NULL, {NULL} }
, { "aries", "\u2648", NULL, {NULL} }
, { "arrow_backward", "\u25c0\ufe0f", NULL, {NULL} }
, { "arrow_double_down", "\u23ec", NULL, {NULL} }
, { "arrow_double_up", "\u23eb", NULL, {NULL} }
, { "arrow_down", "\u2b07\ufe0f", NULL, {NULL} }
, { "arrow_down_small", "\u1f53D", NULL, {NULL} }
, { "arrow_forward", "\u25b6\ufe0f", NULL, {NULL} }
, { "arrow_heading_down", "\u2935\ufe0f", NULL, {NULL} }
, { "arrow_heading_up", "\u2934\ufe0f", NULL, {NULL} }
, { "arrow_left", "\u2b05\ufe0f", NULL, {NULL} }
, { "arrow_lower_left", "\u2199\ufe0f", NULL, {NULL} }
, { "arrow_lower_right", "\u2198\ufe0f", NULL, {NULL} }
, { "arrow_right", "\u27a1\ufe0f", NULL, {NULL} }
, { "arrow_right_hook", "\u21aa\ufe0f", NULL, {NULL} }
, { "arrow_up", "\u2b06\ufe0f", NULL, {NULL} }
, { "arrow_up_down", "\u2195\ufe0f", NULL, {NULL} }
, { "arrow_up_small", "\u1f53C", NULL, {NULL} }
, { "arrow_upper_left", "\u2196\ufe0f", NULL, {NULL} }
, { "arrow_upper_right", "\u2197\ufe0f", NULL, {NULL} }
, { "arrows_clockwise", "\u1f503", NULL, {NULL} }
, { "arrows_counterclockwise", "\u1f504", NULL, {NULL} }
, { "art", "\u1f3a8", NULL, {NULL} }
, { "articulated_lorry", "\u1f69B", NULL, {NULL} }
, { "astonished", "\u1f632", NULL, {NULL} }
, { "athletic_shoe", "\u1f45F", NULL, {NULL} }
, { "atm", "\u1f3e7", NULL, {NULL} }
, { "atom_symbol", "\u269b\ufe0f", NULL, {NULL} }
, { "avocado", "\u1f951", NULL, {NULL} }
, { "b", "\u1f171\ufe0f", NULL, {NULL} }
, { "baby", "\u1f476", NULL, {NULL} }
, { "baby_bottle", "\u1f37C", NULL, {NULL} }
, { "baby_chick", "\u1f424", NULL, {NULL} }
, { "baby_symbol", "\u1f6bC", NULL, {NULL} }
, { "back", "\u1f519", NULL, {NULL} }
, { "bacon", "\u1f953", NULL, {NULL} }
, { "badminton_racquet_and_shuttlecock", "\u1f3f8", NULL, {NULL} }
, { "baggage_claim", "\u1f6c4", NULL, {NULL} }
, { "baguette_bread", "\u1f956", NULL, {NULL} }
, { "balloon", "\u1f388", NULL, {NULL} }
, { "ballot_box_with_ballot", "\u1f5f3\ufe0f", NULL, {NULL} }
, { "ballot_box_with_check", "\u2611\ufe0f", NULL, {NULL} }
, { "bamboo", "\u1f38D", NULL, {NULL} }
, { "banana", "\u1f34C", NULL, {NULL} }
, { "bangbang", "\u203c\ufe0f", NULL, {NULL} }
, { "bank", "\u1f3e6", NULL, {NULL} }
, { "bar_chart", "\u1f4cA", NULL, {NULL} }
, { "barber", "\u1f488", NULL, {NULL} }
, { "barely_sunny", "\u1f325\ufe0f", NULL, {NULL} }
, { "baseball", "\u26be", NULL, {NULL} }
, { "basketball", "\u1f3c0", NULL, {NULL} }
, { "bat", "\u1f987", NULL, {NULL} }
, { "bath", "\u1f6c0", NULL, {NULL} }
, { "bathtub", "\u1f6c1", NULL, {NULL} }
, { "battery", "\u1f50B", NULL, {NULL} }
, { "beach_with_umbrella", "\u1f3d6\ufe0f", NULL, {NULL} }
, { "bear", "\u1f43B", NULL, {NULL} }
, { "bearded_person", "\u1f9d4", NULL, {NULL} }
, { "bed", "\u1f6cF\ufe0f", NULL, {NULL} }
, { "bee", "\u1f41D", NULL, {NULL} }
, { "beer", "\u1f37A", NULL, {NULL} }
, { "beers", "\u1f37B", NULL, {NULL} }
, { "beetle", "\u1f41E", NULL, {NULL} }
, { "beginner", "\u1f530", NULL, {NULL} }
, { "bell", "\u1f514", NULL, {NULL} }
, { "bellhop_bell", "\u1f6cE\ufe0f", NULL, {NULL} }
, { "bento", "\u1f371", NULL, {NULL} }
, { "bicyclist", "\u1f6b4", NULL, {NULL} }
, { "bike", "\u1f6b2", NULL, {NULL} }
, { "bikini", "\u1f459", NULL, {NULL} }
, { "billed_cap", "\u1f9e2", NULL, {NULL} }
, { "biohazard_sign", "\u2623\ufe0f", NULL, {NULL} }
, { "bird", "\u1f426", NULL, {NULL} }
, { "birthday", "\u1f382", NULL, {NULL} }
, { "black_circle", "\u26ab", NULL, {NULL} }
, { "black_circle_for_record", "\u23fa\ufe0f", NULL, {NULL} }
, { "black_heart", "\u1f5a4", NULL, {NULL} }
, { "black_joker", "\u1f0cF", NULL, {NULL} }
, { "black_large_square", "\u2b1b", NULL, {NULL} }
, { "black_left_pointing_double_triangle_with_vertical_bar", "\u23ee\ufe0f", NULL, {NULL} }
, { "black_medium_small_square", "\u25fe", NULL, {NULL} }
, { "black_medium_square", "\u25fc\ufe0f", NULL, {NULL} }
, { "black_nib", "\u2712\ufe0f", NULL, {NULL} }
, { "black_right_pointing_double_triangle_with_vertical_bar", "\u23ed\ufe0f", NULL, {NULL} }
, { "black_right_pointing_triangle_with_double_vertical_bar", "\u23ef\ufe0f", NULL, {NULL} }
, { "black_small_square", "\u25aa\ufe0f", NULL, {NULL} }
, { "black_square_button", "\u1f532", NULL, {NULL} }
, { "black_square_for_stop", "\u23f9\ufe0f", NULL, {NULL} }
, { "blond-haired-man", "\u1f471\u200d\u2642\ufe0f", NULL, {NULL} }
, { "blond-haired-woman", "\u1f471\u200d\u2640\ufe0f", NULL, {NULL} }
, { "blossom", "\u1f33C", NULL, {NULL} }
, { "blowfish", "\u1f421", NULL, {NULL} }
, { "blue_book", "\u1f4d8", NULL, {NULL} }
, { "blue_car", "\u1f699", NULL, {NULL} }
, { "blue_heart", "\u1f499", "<3", {NULL} }
, { "blush", "\u1f60A", ":)", {NULL} }
, { "boar", "\u1f417", NULL, {NULL} }
, { "boat", "\u26f5", NULL, {NULL} }
, { "bomb", "\u1f4a3", NULL, {NULL} }
, { "book", "\u1f4d6", NULL, {NULL} }
, { "bookmark", "\u1f516", NULL, {NULL} }
, { "bookmark_tabs", "\u1f4d1", NULL, {NULL} }
, { "books", "\u1f4dA", NULL, {NULL} }
, { "boom", "\u1f4a5", NULL, {NULL} }
, { "boot", "\u1f462", NULL, {NULL} }
, { "bouquet", "\u1f490", NULL, {NULL} }
, { "bow", "\u1f647", NULL, {NULL} }
, { "bow_and_arrow", "\u1f3f9", NULL, {NULL} }
, { "bowl_with_spoon", "\u1f963", NULL, {NULL} }
, { "bowling", "\u1f3b3", NULL, {NULL} }
, { "boxing_glove", "\u1f94A", NULL, {NULL} }
, { "boy", "\u1f466", NULL, {NULL} }
, { "brain", "\u1f9e0", NULL, {NULL} }
, { "bread", "\u1f35E", NULL, {NULL} }
, { "breast-feeding", "\u1f931", NULL, {NULL} }
, { "bride_with_veil", "\u1f470", NULL, {NULL} }
, { "bridge_at_night", "\u1f309", NULL, {NULL} }
, { "briefcase", "\u1f4bC", NULL, {NULL} }
, { "broccoli", "\u1f966", NULL, {NULL} }
, { "broken_heart", "\u1f494", "</3", {"</3", NULL} }
, { "bug", "\u1f41B", NULL, {NULL} }
, { "building_construction", "\u1f3d7\ufe0f", NULL, {NULL} }
, { "bulb", "\u1f4a1", NULL, {NULL} }
, { "bullettrain_front", "\u1f685", NULL, {NULL} }
, { "bullettrain_side", "\u1f684", NULL, {NULL} }
, { "burrito", "\u1f32F", NULL, {NULL} }
, { "bus", "\u1f68C", NULL, {NULL} }
, { "busstop", "\u1f68F", NULL, {NULL} }
, { "bust_in_silhouette", "\u1f464", NULL, {NULL} }
, { "busts_in_silhouette", "\u1f465", NULL, {NULL} }
, { "butterfly", "\u1f98B", NULL, {NULL} }
, { "cactus", "\u1f335", NULL, {NULL} }
, { "cake", "\u1f370", NULL, {NULL} }
, { "calendar", "\u1f4c6", NULL, {NULL} }
, { "call_me_hand", "\u1f919", NULL, {NULL} }
, { "calling", "\u1f4f2", NULL, {NULL} }
, { "camel", "\u1f42B", NULL, {NULL} }
, { "camera", "\u1f4f7", NULL, {NULL} }
, { "camera_with_flash", "\u1f4f8", NULL, {NULL} }
, { "camping", "\u1f3d5\ufe0f", NULL, {NULL} }
, { "cancer", "\u264b", NULL, {NULL} }
, { "candle", "\u1f56F\ufe0f", NULL, {NULL} }
, { "candy", "\u1f36C", NULL, {NULL} }
, { "canned_food", "\u1f96B", NULL, {NULL} }
, { "canoe", "\u1f6f6", NULL, {NULL} }
, { "capital_abcd", "\u1f520", NULL, {NULL} }
, { "capricorn", "\u2651", NULL, {NULL} }
, { "car", "\u1f697", NULL, {NULL} }
, { "card_file_box", "\u1f5c3\ufe0f", NULL, {NULL} }
, { "card_index", "\u1f4c7", NULL, {NULL} }
, { "card_index_dividers", "\u1f5c2\ufe0f", NULL, {NULL} }
, { "carousel_horse", "\u1f3a0", NULL, {NULL} }
, { "carrot", "\u1f955", NULL, {NULL} }
, { "cat", "\u1f431", NULL, {NULL} }
, { "cat2", "\u1f408", NULL, {NULL} }
, { "cd", "\u1f4bF", NULL, {NULL} }
, { "chains", "\u26d3\ufe0f", NULL, {NULL} }
, { "champagne", "\u1f37E", NULL, {NULL} }
, { "chart", "\u1f4b9", NULL, {NULL} }
, { "chart_with_downwards_trend", "\u1f4c9", NULL, {NULL} }
, { "chart_with_upwards_trend", "\u1f4c8", NULL, {NULL} }
, { "checkered_flag", "\u1f3c1", NULL, {NULL} }
, { "cheese_wedge", "\u1f9c0", NULL, {NULL} }
, { "cherries", "\u1f352", NULL, {NULL} }
, { "cherry_blossom", "\u1f338", NULL, {NULL} }
, { "chestnut", "\u1f330", NULL, {NULL} }
, { "chicken", "\u1f414", NULL, {NULL} }
, { "child", "\u1f9d2", NULL, {NULL} }
, { "children_crossing", "\u1f6b8", NULL, {NULL} }
, { "chipmunk", "\u1f43F\ufe0f", NULL, {NULL} }
, { "chocolate_bar", "\u1f36B", NULL, {NULL} }
, { "chopsticks", "\u1f962", NULL, {NULL} }
, { "christmas_tree", "\u1f384", NULL, {NULL} }
, { "church", "\u26ea", NULL, {NULL} }
, { "cinema", "\u1f3a6", NULL, {NULL} }
, { "circus_tent", "\u1f3aA", NULL, {NULL} }
, { "city_sunrise", "\u1f307", NULL, {NULL} }
, { "city_sunset", "\u1f306", NULL, {NULL} }
, { "cityscape", "\u1f3d9\ufe0f", NULL, {NULL} }
, { "cl", "\u1f191", NULL, {NULL} }
, { "clap", "\u1f44F", NULL, {NULL} }
, { "clapper", "\u1f3aC", NULL, {NULL} }
, { "classical_building", "\u1f3dB\ufe0f", NULL, {NULL} }
, { "clinking_glasses", "\u1f942", NULL, {NULL} }
, { "clipboard", "\u1f4cB", NULL, {NULL} }
, { "clock1", "\u1f550", NULL, {NULL} }
, { "clock10", "\u1f559", NULL, {NULL} }
, { "clock1030", "\u1f565", NULL, {NULL} }
, { "clock11", "\u1f55A", NULL, {NULL} }
, { "clock1130", "\u1f566", NULL, {NULL} }
, { "clock12", "\u1f55B", NULL, {NULL} }
, { "clock1230", "\u1f567", NULL, {NULL} }
, { "clock130", "\u1f55C", NULL, {NULL} }
, { "clock2", "\u1f551", NULL, {NULL} }
, { "clock230", "\u1f55D", NULL, {NULL} }
, { "clock3", "\u1f552", NULL, {NULL} }
, { "clock330", "\u1f55E", NULL, {NULL} }
, { "clock4", "\u1f553", NULL, {NULL} }
, { "clock430", "\u1f55F", NULL, {NULL} }
, { "clock5", "\u1f554", NULL, {NULL} }
, { "clock530", "\u1f560", NULL, {NULL} }
, { "clock6", "\u1f555", NULL, {NULL} }
, { "clock630", "\u1f561", NULL, {NULL} }
, { "clock7", "\u1f556", NULL, {NULL} }
, { "clock730", "\u1f562", NULL, {NULL} }
, { "clock8", "\u1f557", NULL, {NULL} }
, { "clock830", "\u1f563", NULL, {NULL} }
, { "clock9", "\u1f558", NULL, {NULL} }
, { "clock930", "\u1f564", NULL, {NULL} }
, { "closed_book", "\u1f4d5", NULL, {NULL} }
, { "closed_lock_with_key", "\u1f510", NULL, {NULL} }
, { "closed_umbrella", "\u1f302", NULL, {NULL} }
, { "cloud", "\u2601\ufe0f", NULL, {NULL} }
, { "clown_face", "\u1f921", NULL, {NULL} }
, { "clubs", "\u2663\ufe0f", NULL, {NULL} }
, { "cn", "\u1f1e8\u1f1f3", NULL, {NULL} }
, { "coat", "\u1f9e5", NULL, {NULL} }
, { "cocktail", "\u1f378", NULL, {NULL} }
, { "coconut", "\u1f965", NULL, {NULL} }
, { "coffee", "\u2615", NULL, {NULL} }
, { "coffin", "\u26b0\ufe0f", NULL, {NULL} }
, { "cold_sweat", "\u1f630", NULL, {NULL} }
, { "collision", "\u1f4a5", NULL, {NULL} }
, { "comet", "\u2604\ufe0f", NULL, {NULL} }
, { "compression", "\u1f5dC\ufe0f", NULL, {NULL} }
, { "computer", "\u1f4bB", NULL, {NULL} }
, { "confetti_ball", "\u1f38A", NULL, {NULL} }
, { "confounded", "\u1f616", NULL, {NULL} }
, { "confused", "\u1f615", NULL, {":\\", ":-\\", ":/", ":-/", NULL} }
, { "congratulations", "\u3297\ufe0f", NULL, {NULL} }
, { "construction", "\u1f6a7", NULL, {NULL} }
, { "construction_worker", "\u1f477", NULL, {NULL} }
, { "control_knobs", "\u1f39B\ufe0f", NULL, {NULL} }
, { "convenience_store", "\u1f3eA", NULL, {NULL} }
, { "cookie", "\u1f36A", NULL, {NULL} }
, { "cooking", "\u1f373", NULL, {NULL} }
, { "cool", "\u1f192", NULL, {NULL} }
, { "cop", "\u1f46E", NULL, {NULL} }
, { "copyright", "\u00a9\ufe0f", NULL, {NULL} }
, { "corn", "\u1f33D", NULL, {NULL} }
, { "couch_and_lamp", "\u1f6cB\ufe0f", NULL, {NULL} }
, { "couple", "\u1f46B", NULL, {NULL} }
, { "couple_with_heart", "\u1f491", NULL, {NULL} }
, { "couplekiss", "\u1f48F", NULL, {NULL} }
, { "cow", "\u1f42E", NULL, {NULL} }
, { "cow2", "\u1f404", NULL, {NULL} }
, { "crab", "\u1f980", NULL, {NULL} }
, { "credit_card", "\u1f4b3", NULL, {NULL} }
, { "crescent_moon", "\u1f319", NULL, {NULL} }
, { "cricket", "\u1f997", NULL, {NULL} }
, { "cricket_bat_and_ball", "\u1f3cF", NULL, {NULL} }
, { "crocodile", "\u1f40A", NULL, {NULL} }
, { "croissant", "\u1f950", NULL, {NULL} }
, { "crossed_fingers", "\u1f91E", NULL, {NULL} }
, { "crossed_flags", "\u1f38C", NULL, {NULL} }
, { "crossed_swords", "\u2694\ufe0f", NULL, {NULL} }
, { "crown", "\u1f451", NULL, {NULL} }
, { "cry", "\u1f622", ":'(", {":'(", NULL} }
, { "crying_cat_face", "\u1f63F", NULL, {NULL} }
, { "crystal_ball", "\u1f52E", NULL, {NULL} }
, { "cucumber", "\u1f952", NULL, {NULL} }
, { "cup_with_straw", "\u1f964", NULL, {NULL} }
, { "cupid", "\u1f498", NULL, {NULL} }
, { "curling_stone", "\u1f94C", NULL, {NULL} }
, { "curly_loop", "\u27b0", NULL, {NULL} }
, { "currency_exchange", "\u1f4b1", NULL, {NULL} }
, { "curry", "\u1f35B", NULL, {NULL} }
, { "custard", "\u1f36E", NULL, {NULL} }
, { "customs", "\u1f6c3", NULL, {NULL} }
, { "cut_of_meat", "\u1f969", NULL, {NULL} }
, { "cyclone", "\u1f300", NULL, {NULL} }
, { "dagger_knife", "\u1f5e1\ufe0f", NULL, {NULL} }
, { "dancer", "\u1f483", NULL, {NULL} }
, { "dancers", "\u1f46F", NULL, {NULL} }
, { "dango", "\u1f361", NULL, {NULL} }
, { "dark_sunglasses", "\u1f576\ufe0f", NULL, {NULL} }
, { "dart", "\u1f3aF", NULL, {NULL} }
, { "dash", "\u1f4a8", NULL, {NULL} }
, { "date", "\u1f4c5", NULL, {NULL} }
, { "de", "\u1f1e9\u1f1eA", NULL, {NULL} }
, { "deciduous_tree", "\u1f333", NULL, {NULL} }
, { "deer", "\u1f98C", NULL, {NULL} }
, { "department_store", "\u1f3eC", NULL, {NULL} }
, { "derelict_house_building", "\u1f3dA\ufe0f", NULL, {NULL} }
, { "desert", "\u1f3dC\ufe0f", NULL, {NULL} }
, { "desert_island", "\u1f3dD\ufe0f", NULL, {NULL} }
, { "desktop_computer", "\u1f5a5\ufe0f", NULL, {NULL} }
, { "diamond_shape_with_a_dot_inside", "\u1f4a0", NULL, {NULL} }
, { "diamonds", "\u2666\ufe0f", NULL, {NULL} }
, { "disappointed", "\u1f61E", ":(", {"):", ":(", ":-(", NULL} }
, { "disappointed_relieved", "\u1f625", NULL, {NULL} }
, { "dizzy", "\u1f4aB", NULL, {NULL} }
, { "dizzy_face", "\u1f635", NULL, {NULL} }
, { "do_not_litter", "\u1f6aF", NULL, {NULL} }
, { "dog", "\u1f436", NULL, {NULL} }
, { "dog2", "\u1f415", NULL, {NULL} }
, { "dollar", "\u1f4b5", NULL, {NULL} }
, { "dolls", "\u1f38E", NULL, {NULL} }
, { "dolphin", "\u1f42C", NULL, {NULL} }
, { "door", "\u1f6aA", NULL, {NULL} }
, { "double_vertical_bar", "\u23f8\ufe0f", NULL, {NULL} }
, { "doughnut", "\u1f369", NULL, {NULL} }
, { "dove_of_peace", "\u1f54A\ufe0f", NULL, {NULL} }
, { "dragon", "\u1f409", NULL, {NULL} }
, { "dragon_face", "\u1f432", NULL, {NULL} }
, { "dress", "\u1f457", NULL, {NULL} }
, { "dromedary_camel", "\u1f42A", NULL, {NULL} }
, { "drooling_face", "\u1f924", NULL, {NULL} }
, { "droplet", "\u1f4a7", NULL, {NULL} }
, { "drum_with_drumsticks", "\u1f941", NULL, {NULL} }
, { "duck", "\u1f986", NULL, {NULL} }
, { "dumpling", "\u1f95F", NULL, {NULL} }
, { "dvd", "\u1f4c0", NULL, {NULL} }
, { "e-mail", "\u1f4e7", NULL, {NULL} }
, { "eagle", "\u1f985", NULL, {NULL} }
, { "ear", "\u1f442", NULL, {NULL} }
, { "ear_of_rice", "\u1f33E", NULL, {NULL} }
, { "earth_africa", "\u1f30D", NULL, {NULL} }
, { "earth_americas", "\u1f30E", NULL, {NULL} }
, { "earth_asia", "\u1f30F", NULL, {NULL} }
, { "egg", "\u1f95A", NULL, {NULL} }
, { "eggplant", "\u1f346", NULL, {NULL} }
, { "eight", "8\ufe0f\u20e3", NULL, {NULL} }
, { "eight_pointed_black_star", "\u2734\ufe0f", NULL, {NULL} }
, { "eight_spoked_asterisk", "\u2733\ufe0f", NULL, {NULL} }
, { "eject", "\u23cf\ufe0f", NULL, {NULL} }
, { "electric_plug", "\u1f50C", NULL, {NULL} }
, { "elephant", "\u1f418", NULL, {NULL} }
, { "elf", "\u1f9dD", NULL, {NULL} }
, { "email", "\u2709\ufe0f", NULL, {NULL} }
, { "end", "\u1f51A", NULL, {NULL} }
, { "envelope", "\u2709\ufe0f", NULL, {NULL} }
, { "envelope_with_arrow", "\u1f4e9", NULL, {NULL} }
, { "es", "\u1f1eA\u1f1f8", NULL, {NULL} }
, { "euro", "\u1f4b6", NULL, {NULL} }
, { "european_castle", "\u1f3f0", NULL, {NULL} }
, { "european_post_office", "\u1f3e4", NULL, {NULL} }
, { "evergreen_tree", "\u1f332", NULL, {NULL} }
, { "exclamation", "\u2757", NULL, {NULL} }
, { "exploding_head", "\u1f92F", NULL, {NULL} }
, { "expressionless", "\u1f611", NULL, {NULL} }
, { "eye", "\u1f441\ufe0f", NULL, {NULL} }
, { "eye-in-speech-bubble", "\u1f441\ufe0f\u200d\u1f5e8\ufe0f", NULL, {NULL} }
, { "eyeglasses", "\u1f453", NULL, {NULL} }
, { "eyes", "\u1f440", NULL, {NULL} }
, { "face_palm", "\u1f926", NULL, {NULL} }
, { "face_vomiting", "\u1f92E", NULL, {NULL} }
, { "face_with_cowboy_hat", "\u1f920", NULL, {NULL} }
, { "face_with_finger_covering_closed_lips", "\u1f92B", NULL, {NULL} }
, { "face_with_hand_over_mouth", "\u1f92D", NULL, {NULL} }
, { "face_with_head_bandage", "\u1f915", NULL, {NULL} }
, { "face_with_monocle", "\u1f9d0", NULL, {NULL} }
, { "face_with_one_eyebrow_raised", "\u1f928", NULL, {NULL} }
, { "face_with_open_mouth_vomiting", "\u1f92E", NULL, {NULL} }
, { "face_with_raised_eyebrow", "\u1f928", NULL, {NULL} }
, { "face_with_rolling_eyes", "\u1f644", NULL, {NULL} }
, { "face_with_symbols_on_mouth", "\u1f92C", NULL, {NULL} }
, { "face_with_thermometer", "\u1f912", NULL, {NULL} }
, { "facepunch", "\u1f44A", NULL, {NULL} }
, { "factory", "\u1f3eD", NULL, {NULL} }
, { "fairy", "\u1f9dA", NULL, {NULL} }
, { "fallen_leaf", "\u1f342", NULL, {NULL} }
, { "family", "\u1f468\u200d\u1f469\u200d\u1f466", NULL, {NULL} }
, { "family", "\u1f46A", NULL, {NULL} }
, { "fast_forward", "\u23e9", NULL, {NULL} }
, { "fax", "\u1f4e0", NULL, {NULL} }
, { "fearful", "\u1f628", NULL, {NULL} }
, { "feet", "\u1f43E", NULL, {NULL} }
, { "female-artist", "\u1f469\u200d\u1f3a8", NULL, {NULL} }
, { "female-astronaut", "\u1f469\u200d\u1f680", NULL, {NULL} }
, { "female-construction-worker", "\u1f477\u200d\u2640\ufe0f", NULL, {NULL} }
, { "female-cook", "\u1f469\u200d\u1f373", NULL, {NULL} }
, { "female-detective", "\u1f575\ufe0f\u200d\u2640\ufe0f", NULL, {NULL} }
, { "female-doctor", "\u1f469\u200d\u2695\ufe0f", NULL, {NULL} }
, { "female-factory-worker", "\u1f469\u200d\u1f3eD", NULL, {NULL} }
, { "female-farmer", "\u1f469\u200d\u1f33E", NULL, {NULL} }
, { "female-firefighter", "\u1f469\u200d\u1f692", NULL, {NULL} }
, { "female-guard", "\u1f482\u200d\u2640\ufe0f", NULL, {NULL} }
, { "female-judge", "\u1f469\u200d\u2696\ufe0f", NULL, {NULL} }
, { "female-mechanic", "\u1f469\u200d\u1f527", NULL, {NULL} }
, { "female-office-worker", "\u1f469\u200d\u1f4bC", NULL, {NULL} }
, { "female-pilot", "\u1f469\u200d\u2708\ufe0f", NULL, {NULL} }
, { "female-police-officer", "\u1f46E\u200d\u2640\ufe0f", NULL, {NULL} }
, { "female-scientist", "\u1f469\u200d\u1f52C", NULL, {NULL} }
, { "female-singer", "\u1f469\u200d\u1f3a4", NULL, {NULL} }
, { "female-student", "\u1f469\u200d\u1f393", NULL, {NULL} }
, { "female-teacher", "\u1f469\u200d\u1f3eB", NULL, {NULL} }
, { "female-technologist", "\u1f469\u200d\u1f4bB", NULL, {NULL} }
, { "female_elf", "\u1f9dD\u200d\u2640\ufe0f", NULL, {NULL} }
, { "female_fairy", "\u1f9dA\u200d\u2640\ufe0f", NULL, {NULL} }
, { "female_genie", "\u1f9dE\u200d\u2640\ufe0f", NULL, {NULL} }
, { "female_mage", "\u1f9d9\u200d\u2640\ufe0f", NULL, {NULL} }
, { "female_sign", "\u2640\ufe0f", NULL, {NULL} }
, { "female_vampire", "\u1f9dB\u200d\u2640\ufe0f", NULL, {NULL} }
, { "female_zombie", "\u1f9dF\u200d\u2640\ufe0f", NULL, {NULL} }
, { "fencer", "\u1f93A", NULL, {NULL} }
, { "ferris_wheel", "\u1f3a1", NULL, {NULL} }
, { "ferry", "\u26f4\ufe0f", NULL, {NULL} }
, { "field_hockey_stick_and_ball", "\u1f3d1", NULL, {NULL} }
, { "file_cabinet", "\u1f5c4\ufe0f", NULL, {NULL} }
, { "file_folder", "\u1f4c1", NULL, {NULL} }
, { "film_frames", "\u1f39E\ufe0f", NULL, {NULL} }
, { "film_projector", "\u1f4fD\ufe0f", NULL, {NULL} }
, { "fire", "\u1f525", NULL, {NULL} }
, { "fire_engine", "\u1f692", NULL, {NULL} }
, { "fireworks", "\u1f386", NULL, {NULL} }
, { "first_place_medal", "\u1f947", NULL, {NULL} }
, { "first_quarter_moon", "\u1f313", NULL, {NULL} }
, { "first_quarter_moon_with_face", "\u1f31B", NULL, {NULL} }
, { "fish", "\u1f41F", NULL, {NULL} }
, { "fish_cake", "\u1f365", NULL, {NULL} }
, { "fishing_pole_and_fish", "\u1f3a3", NULL, {NULL} }
, { "fist", "\u270a", NULL, {NULL} }
, { "five", "5\ufe0f\u20e3", NULL, {NULL} }
, { "flag-ac", "\u1f1e6\u1f1e8", NULL, {NULL} }
, { "flag-ad", "\u1f1e6\u1f1e9", NULL, {NULL} }
, { "flag-ae", "\u1f1e6\u1f1eA", NULL, {NULL} }
, { "flag-af", "\u1f1e6\u1f1eB", NULL, {NULL} }
, { "flag-ag", "\u1f1e6\u1f1eC", NULL, {NULL} }
, { "flag-ai", "\u1f1e6\u1f1eE", NULL, {NULL} }
, { "flag-al", "\u1f1e6\u1f1f1", NULL, {NULL} }
, { "flag-am", "\u1f1e6\u1f1f2", NULL, {NULL} }
, { "flag-ao", "\u1f1e6\u1f1f4", NULL, {NULL} }
, { "flag-aq", "\u1f1e6\u1f1f6", NULL, {NULL} }
, { "flag-ar", "\u1f1e6\u1f1f7", NULL, {NULL} }
, { "flag-as", "\u1f1e6\u1f1f8", NULL, {NULL} }
, { "flag-at", "\u1f1e6\u1f1f9", NULL, {NULL} }
, { "flag-au", "\u1f1e6\u1f1fA", NULL, {NULL} }
, { "flag-aw", "\u1f1e6\u1f1fC", NULL, {NULL} }
, { "flag-ax", "\u1f1e6\u1f1fD", NULL, {NULL} }
, { "flag-az", "\u1f1e6\u1f1fF", NULL, {NULL} }
, { "flag-ba", "\u1f1e7\u1f1e6", NULL, {NULL} }
, { "flag-bb", "\u1f1e7\u1f1e7", NULL, {NULL} }
, { "flag-bd", "\u1f1e7\u1f1e9", NULL, {NULL} }
, { "flag-be", "\u1f1e7\u1f1eA", NULL, {NULL} }
, { "flag-bf", "\u1f1e7\u1f1eB", NULL, {NULL} }
, { "flag-bg", "\u1f1e7\u1f1eC", NULL, {NULL} }
, { "flag-bh", "\u1f1e7\u1f1eD", NULL, {NULL} }
, { "flag-bi", "\u1f1e7\u1f1eE", NULL, {NULL} }
, { "flag-bj", "\u1f1e7\u1f1eF", NULL, {NULL} }
, { "flag-bl", "\u1f1e7\u1f1f1", NULL, {NULL} }
, { "flag-bm", "\u1f1e7\u1f1f2", NULL, {NULL} }
, { "flag-bn", "\u1f1e7\u1f1f3", NULL, {NULL} }
, { "flag-bo", "\u1f1e7\u1f1f4", NULL, {NULL} }
, { "flag-bq", "\u1f1e7\u1f1f6", NULL, {NULL} }
, { "flag-br", "\u1f1e7\u1f1f7", NULL, {NULL} }
, { "flag-bs", "\u1f1e7\u1f1f8", NULL, {NULL} }
, { "flag-bt", "\u1f1e7\u1f1f9", NULL, {NULL} }
, { "flag-bv", "\u1f1e7\u1f1fB", NULL, {NULL} }
, { "flag-bw", "\u1f1e7\u1f1fC", NULL, {NULL} }
, { "flag-by", "\u1f1e7\u1f1fE", NULL, {NULL} }
, { "flag-bz", "\u1f1e7\u1f1fF", NULL, {NULL} }
, { "flag-ca", "\u1f1e8\u1f1e6", NULL, {NULL} }
, { "flag-cc", "\u1f1e8\u1f1e8", NULL, {NULL} }
, { "flag-cd", "\u1f1e8\u1f1e9", NULL, {NULL} }
, { "flag-cf", "\u1f1e8\u1f1eB", NULL, {NULL} }
, { "flag-cg", "\u1f1e8\u1f1eC", NULL, {NULL} }
, { "flag-ch", "\u1f1e8\u1f1eD", NULL, {NULL} }
, { "flag-ci", "\u1f1e8\u1f1eE", NULL, {NULL} }
, { "flag-ck", "\u1f1e8\u1f1f0", NULL, {NULL} }
, { "flag-cl", "\u1f1e8\u1f1f1", NULL, {NULL} }
, { "flag-cm", "\u1f1e8\u1f1f2", NULL, {NULL} }
, { "flag-cn", "\u1f1e8\u1f1f3", NULL, {NULL} }
, { "flag-co", "\u1f1e8\u1f1f4", NULL, {NULL} }
, { "flag-cp", "\u1f1e8\u1f1f5", NULL, {NULL} }
, { "flag-cr", "\u1f1e8\u1f1f7", NULL, {NULL} }
, { "flag-cu", "\u1f1e8\u1f1fA", NULL, {NULL} }
, { "flag-cv", "\u1f1e8\u1f1fB", NULL, {NULL} }
, { "flag-cw", "\u1f1e8\u1f1fC", NULL, {NULL} }
, { "flag-cx", "\u1f1e8\u1f1fD", NULL, {NULL} }
, { "flag-cy", "\u1f1e8\u1f1fE", NULL, {NULL} }
, { "flag-cz", "\u1f1e8\u1f1fF", NULL, {NULL} }
, { "flag-de", "\u1f1e9\u1f1eA", NULL, {NULL} }
, { "flag-dg", "\u1f1e9\u1f1eC", NULL, {NULL} }
, { "flag-dj", "\u1f1e9\u1f1eF", NULL, {NULL} }
, { "flag-dk", "\u1f1e9\u1f1f0", NULL, {NULL} }
, { "flag-dm", "\u1f1e9\u1f1f2", NULL, {NULL} }
, { "flag-do", "\u1f1e9\u1f1f4", NULL, {NULL} }
, { "flag-dz", "\u1f1e9\u1f1fF", NULL, {NULL} }
, { "flag-ea", "\u1f1eA\u1f1e6", NULL, {NULL} }
, { "flag-ec", "\u1f1eA\u1f1e8", NULL, {NULL} }
, { "flag-ee", "\u1f1eA\u1f1eA", NULL, {NULL} }
, { "flag-eg", "\u1f1eA\u1f1eC", NULL, {NULL} }
, { "flag-eh", "\u1f1eA\u1f1eD", NULL, {NULL} }
, { "flag-england", "\u1f3f4\ue0067\ue0062\ue0065\ue006E\ue0067\ue007F", NULL, {NULL} }
, { "flag-er", "\u1f1eA\u1f1f7", NULL, {NULL} }
, { "flag-es", "\u1f1eA\u1f1f8", NULL, {NULL} }
, { "flag-et", "\u1f1eA\u1f1f9", NULL, {NULL} }
, { "flag-eu", "\u1f1eA\u1f1fA", NULL, {NULL} }
, { "flag-fi", "\u1f1eB\u1f1eE", NULL, {NULL} }
, { "flag-fj", "\u1f1eB\u1f1eF", NULL, {NULL} }
, { "flag-fk", "\u1f1eB\u1f1f0", NULL, {NULL} }
, { "flag-fm", "\u1f1eB\u1f1f2", NULL, {NULL} }
, { "flag-fo", "\u1f1eB\u1f1f4", NULL, {NULL} }
, { "flag-fr", "\u1f1eB\u1f1f7", NULL, {NULL} }
, { "flag-ga", "\u1f1eC\u1f1e6", NULL, {NULL} }
, { "flag-gb", "\u1f1eC\u1f1e7", NULL, {NULL} }
, { "flag-gd", "\u1f1eC\u1f1e9", NULL, {NULL} }
, { "flag-ge", "\u1f1eC\u1f1eA", NULL, {NULL} }
, { "flag-gf", "\u1f1eC\u1f1eB", NULL, {NULL} }
, { "flag-gg", "\u1f1eC\u1f1eC", NULL, {NULL} }
, { "flag-gh", "\u1f1eC\u1f1eD", NULL, {NULL} }
, { "flag-gi", "\u1f1eC\u1f1eE", NULL, {NULL} }
, { "flag-gl", "\u1f1eC\u1f1f1", NULL, {NULL} }
, { "flag-gm", "\u1f1eC\u1f1f2", NULL, {NULL} }
, { "flag-gn", "\u1f1eC\u1f1f3", NULL, {NULL} }
, { "flag-gp", "\u1f1eC\u1f1f5", NULL, {NULL} }
, { "flag-gq", "\u1f1eC\u1f1f6", NULL, {NULL} }
, { "flag-gr", "\u1f1eC\u1f1f7", NULL, {NULL} }
, { "flag-gs", "\u1f1eC\u1f1f8", NULL, {NULL} }
, { "flag-gt", "\u1f1eC\u1f1f9", NULL, {NULL} }
, { "flag-gu", "\u1f1eC\u1f1fA", NULL, {NULL} }
, { "flag-gw", "\u1f1eC\u1f1fC", NULL, {NULL} }
, { "flag-gy", "\u1f1eC\u1f1fE", NULL, {NULL} }
, { "flag-hk", "\u1f1eD\u1f1f0", NULL, {NULL} }
, { "flag-hm", "\u1f1eD\u1f1f2", NULL, {NULL} }
, { "flag-hn", "\u1f1eD\u1f1f3", NULL, {NULL} }
, { "flag-hr", "\u1f1eD\u1f1f7", NULL, {NULL} }
, { "flag-ht", "\u1f1eD\u1f1f9", NULL, {NULL} }
, { "flag-hu", "\u1f1eD\u1f1fA", NULL, {NULL} }
, { "flag-ic", "\u1f1eE\u1f1e8", NULL, {NULL} }
, { "flag-id", "\u1f1eE\u1f1e9", NULL, {NULL} }
, { "flag-ie", "\u1f1eE\u1f1eA", NULL, {NULL} }
, { "flag-il", "\u1f1eE\u1f1f1", NULL, {NULL} }
, { "flag-im", "\u1f1eE\u1f1f2", NULL, {NULL} }
, { "flag-in", "\u1f1eE\u1f1f3", NULL, {NULL} }
, { "flag-io", "\u1f1eE\u1f1f4", NULL, {NULL} }
, { "flag-iq", "\u1f1eE\u1f1f6", NULL, {NULL} }
, { "flag-ir", "\u1f1eE\u1f1f7", NULL, {NULL} }
, { "flag-is", "\u1f1eE\u1f1f8", NULL, {NULL} }
, { "flag-it", "\u1f1eE\u1f1f9", NULL, {NULL} }
, { "flag-je", "\u1f1eF\u1f1eA", NULL, {NULL} }
, { "flag-jm", "\u1f1eF\u1f1f2", NULL, {NULL} }
, { "flag-jo", "\u1f1eF\u1f1f4", NULL, {NULL} }
, { "flag-jp", "\u1f1eF\u1f1f5", NULL, {NULL} }
, { "flag-ke", "\u1f1f0\u1f1eA", NULL, {NULL} }
, { "flag-kg", "\u1f1f0\u1f1eC", NULL, {NULL} }
, { "flag-kh", "\u1f1f0\u1f1eD", NULL, {NULL} }
, { "flag-ki", "\u1f1f0\u1f1eE", NULL, {NULL} }
, { "flag-km", "\u1f1f0\u1f1f2", NULL, {NULL} }
, { "flag-kn", "\u1f1f0\u1f1f3", NULL, {NULL} }
, { "flag-kp", "\u1f1f0\u1f1f5", NULL, {NULL} }
, { "flag-kr", "\u1f1f0\u1f1f7", NULL, {NULL} }
, { "flag-kw", "\u1f1f0\u1f1fC", NULL, {NULL} }
, { "flag-ky", "\u1f1f0\u1f1fE", NULL, {NULL} }
, { "flag-kz", "\u1f1f0\u1f1fF", NULL, {NULL} }
, { "flag-la", "\u1f1f1\u1f1e6", NULL, {NULL} }
, { "flag-lb", "\u1f1f1\u1f1e7", NULL, {NULL} }
, { "flag-lc", "\u1f1f1\u1f1e8", NULL, {NULL} }
, { "flag-li", "\u1f1f1\u1f1eE", NULL, {NULL} }
, { "flag-lk", "\u1f1f1\u1f1f0", NULL, {NULL} }
, { "flag-lr", "\u1f1f1\u1f1f7", NULL, {NULL} }
, { "flag-ls", "\u1f1f1\u1f1f8", NULL, {NULL} }
, { "flag-lt", "\u1f1f1\u1f1f9", NULL, {NULL} }
, { "flag-lu", "\u1f1f1\u1f1fA", NULL, {NULL} }
, { "flag-lv", "\u1f1f1\u1f1fB", NULL, {NULL} }
, { "flag-ly", "\u1f1f1\u1f1fE", NULL, {NULL} }
, { "flag-ma", "\u1f1f2\u1f1e6", NULL, {NULL} }
, { "flag-mc", "\u1f1f2\u1f1e8", NULL, {NULL} }
, { "flag-md", "\u1f1f2\u1f1e9", NULL, {NULL} }
, { "flag-me", "\u1f1f2\u1f1eA", NULL, {NULL} }
, { "flag-mf", "\u1f1f2\u1f1eB", NULL, {NULL} }
, { "flag-mg", "\u1f1f2\u1f1eC", NULL, {NULL} }
, { "flag-mh", "\u1f1f2\u1f1eD", NULL, {NULL} }
, { "flag-mk", "\u1f1f2\u1f1f0", NULL, {NULL} }
, { "flag-ml", "\u1f1f2\u1f1f1", NULL, {NULL} }
, { "flag-mm", "\u1f1f2\u1f1f2", NULL, {NULL} }
, { "flag-mn", "\u1f1f2\u1f1f3", NULL, {NULL} }
, { "flag-mo", "\u1f1f2\u1f1f4", NULL, {NULL} }
, { "flag-mp", "\u1f1f2\u1f1f5", NULL, {NULL} }
, { "flag-mq", "\u1f1f2\u1f1f6", NULL, {NULL} }
, { "flag-mr", "\u1f1f2\u1f1f7", NULL, {NULL} }
, { "flag-ms", "\u1f1f2\u1f1f8", NULL, {NULL} }
, { "flag-mt", "\u1f1f2\u1f1f9", NULL, {NULL} }
, { "flag-mu", "\u1f1f2\u1f1fA", NULL, {NULL} }
, { "flag-mv", "\u1f1f2\u1f1fB", NULL, {NULL} }
, { "flag-mw", "\u1f1f2\u1f1fC", NULL, {NULL} }
, { "flag-mx", "\u1f1f2\u1f1fD", NULL, {NULL} }
, { "flag-my", "\u1f1f2\u1f1fE", NULL, {NULL} }
, { "flag-mz", "\u1f1f2\u1f1fF", NULL, {NULL} }
, { "flag-na", "\u1f1f3\u1f1e6", NULL, {NULL} }
, { "flag-nc", "\u1f1f3\u1f1e8", NULL, {NULL} }
, { "flag-ne", "\u1f1f3\u1f1eA", NULL, {NULL} }
, { "flag-nf", "\u1f1f3\u1f1eB", NULL, {NULL} }
, { "flag-ng", "\u1f1f3\u1f1eC", NULL, {NULL} }
, { "flag-ni", "\u1f1f3\u1f1eE", NULL, {NULL} }
, { "flag-nl", "\u1f1f3\u1f1f1", NULL, {NULL} }
, { "flag-no", "\u1f1f3\u1f1f4", NULL, {NULL} }
, { "flag-np", "\u1f1f3\u1f1f5", NULL, {NULL} }
, { "flag-nr", "\u1f1f3\u1f1f7", NULL, {NULL} }
, { "flag-nu", "\u1f1f3\u1f1fA", NULL, {NULL} }
, { "flag-nz", "\u1f1f3\u1f1fF", NULL, {NULL} }
, { "flag-om", "\u1f1f4\u1f1f2", NULL, {NULL} }
, { "flag-pa", "\u1f1f5\u1f1e6", NULL, {NULL} }
, { "flag-pe", "\u1f1f5\u1f1eA", NULL, {NULL} }
, { "flag-pf", "\u1f1f5\u1f1eB", NULL, {NULL} }
, { "flag-pg", "\u1f1f5\u1f1eC", NULL, {NULL} }
, { "flag-ph", "\u1f1f5\u1f1eD", NULL, {NULL} }
, { "flag-pk", "\u1f1f5\u1f1f0", NULL, {NULL} }
, { "flag-pl", "\u1f1f5\u1f1f1", NULL, {NULL} }
, { "flag-pm", "\u1f1f5\u1f1f2", NULL, {NULL} }
, { "flag-pn", "\u1f1f5\u1f1f3", NULL, {NULL} }
, { "flag-pr", "\u1f1f5\u1f1f7", NULL, {NULL} }
, { "flag-ps", "\u1f1f5\u1f1f8", NULL, {NULL} }
, { "flag-pt", "\u1f1f5\u1f1f9", NULL, {NULL} }
, { "flag-pw", "\u1f1f5\u1f1fC", NULL, {NULL} }
, { "flag-py", "\u1f1f5\u1f1fE", NULL, {NULL} }
, { "flag-qa", "\u1f1f6\u1f1e6", NULL, {NULL} }
, { "flag-re", "\u1f1f7\u1f1eA", NULL, {NULL} }
, { "flag-ro", "\u1f1f7\u1f1f4", NULL, {NULL} }
, { "flag-rs", "\u1f1f7\u1f1f8", NULL, {NULL} }
, { "flag-ru", "\u1f1f7\u1f1fA", NULL, {NULL} }
, { "flag-rw", "\u1f1f7\u1f1fC", NULL, {NULL} }
, { "flag-sa", "\u1f1f8\u1f1e6", NULL, {NULL} }
, { "flag-sb", "\u1f1f8\u1f1e7", NULL, {NULL} }
, { "flag-sc", "\u1f1f8\u1f1e8", NULL, {NULL} }
, { "flag-scotland", "\u1f3f4\ue0067\ue0062\ue0073\ue0063\ue0074\ue007F", NULL, {NULL} }
, { "flag-sd", "\u1f1f8\u1f1e9", NULL, {NULL} }
, { "flag-se", "\u1f1f8\u1f1eA", NULL, {NULL} }
, { "flag-sg", "\u1f1f8\u1f1eC", NULL, {NULL} }
, { "flag-sh", "\u1f1f8\u1f1eD", NULL, {NULL} }
, { "flag-si", "\u1f1f8\u1f1eE", NULL, {NULL} }
, { "flag-sj", "\u1f1f8\u1f1eF", NULL, {NULL} }
, { "flag-sk", "\u1f1f8\u1f1f0", NULL, {NULL} }
, { "flag-sl", "\u1f1f8\u1f1f1", NULL, {NULL} }
, { "flag-sm", "\u1f1f8\u1f1f2", NULL, {NULL} }
, { "flag-sn", "\u1f1f8\u1f1f3", NULL, {NULL} }
, { "flag-so", "\u1f1f8\u1f1f4", NULL, {NULL} }
, { "flag-sr", "\u1f1f8\u1f1f7", NULL, {NULL} }
, { "flag-ss", "\u1f1f8\u1f1f8", NULL, {NULL} }
, { "flag-st", "\u1f1f8\u1f1f9", NULL, {NULL} }
, { "flag-sv", "\u1f1f8\u1f1fB", NULL, {NULL} }
, { "flag-sx", "\u1f1f8\u1f1fD", NULL, {NULL} }
, { "flag-sy", "\u1f1f8\u1f1fE", NULL, {NULL} }
, { "flag-sz", "\u1f1f8\u1f1fF", NULL, {NULL} }
, { "flag-ta", "\u1f1f9\u1f1e6", NULL, {NULL} }
, { "flag-tc", "\u1f1f9\u1f1e8", NULL, {NULL} }
, { "flag-td", "\u1f1f9\u1f1e9", NULL, {NULL} }
, { "flag-tf", "\u1f1f9\u1f1eB", NULL, {NULL} }
, { "flag-tg", "\u1f1f9\u1f1eC", NULL, {NULL} }
, { "flag-th", "\u1f1f9\u1f1eD", NULL, {NULL} }
, { "flag-tj", "\u1f1f9\u1f1eF", NULL, {NULL} }
, { "flag-tk", "\u1f1f9\u1f1f0", NULL, {NULL} }
, { "flag-tl", "\u1f1f9\u1f1f1", NULL, {NULL} }
, { "flag-tm", "\u1f1f9\u1f1f2", NULL, {NULL} }
, { "flag-tn", "\u1f1f9\u1f1f3", NULL, {NULL} }
, { "flag-to", "\u1f1f9\u1f1f4", NULL, {NULL} }
, { "flag-tr", "\u1f1f9\u1f1f7", NULL, {NULL} }
, { "flag-tt", "\u1f1f9\u1f1f9", NULL, {NULL} }
, { "flag-tv", "\u1f1f9\u1f1fB", NULL, {NULL} }
, { "flag-tw", "\u1f1f9\u1f1fC", NULL, {NULL} }
, { "flag-tz", "\u1f1f9\u1f1fF", NULL, {NULL} }
, { "flag-ua", "\u1f1fA\u1f1e6", NULL, {NULL} }
, { "flag-ug", "\u1f1fA\u1f1eC", NULL, {NULL} }
, { "flag-um", "\u1f1fA\u1f1f2", NULL, {NULL} }
, { "flag-un", "\u1f1fA\u1f1f3", NULL, {NULL} }
, { "flag-us", "\u1f1fA\u1f1f8", NULL, {NULL} }
, { "flag-uy", "\u1f1fA\u1f1fE", NULL, {NULL} }
, { "flag-uz", "\u1f1fA\u1f1fF", NULL, {NULL} }
, { "flag-va", "\u1f1fB\u1f1e6", NULL, {NULL} }
, { "flag-vc", "\u1f1fB\u1f1e8", NULL, {NULL} }
, { "flag-ve", "\u1f1fB\u1f1eA", NULL, {NULL} }
, { "flag-vg", "\u1f1fB\u1f1eC", NULL, {NULL} }
, { "flag-vi", "\u1f1fB\u1f1eE", NULL, {NULL} }
, { "flag-vn", "\u1f1fB\u1f1f3", NULL, {NULL} }
, { "flag-vu", "\u1f1fB\u1f1fA", NULL, {NULL} }
, { "flag-wales", "\u1f3f4\ue0067\ue0062\ue0077\ue006C\ue0073\ue007F", NULL, {NULL} }
, { "flag-wf", "\u1f1fC\u1f1eB", NULL, {NULL} }
, { "flag-ws", "\u1f1fC\u1f1f8", NULL, {NULL} }
, { "flag-xk", "\u1f1fD\u1f1f0", NULL, {NULL} }
, { "flag-ye", "\u1f1fE\u1f1eA", NULL, {NULL} }
, { "flag-yt", "\u1f1fE\u1f1f9", NULL, {NULL} }
, { "flag-za", "\u1f1fF\u1f1e6", NULL, {NULL} }
, { "flag-zm", "\u1f1fF\u1f1f2", NULL, {NULL} }
, { "flag-zw", "\u1f1fF\u1f1fC", NULL, {NULL} }
, { "flags", "\u1f38F", NULL, {NULL} }
, { "flashlight", "\u1f526", NULL, {NULL} }
, { "fleur_de_lis", "\u269c\ufe0f", NULL, {NULL} }
, { "flipper", "\u1f42C", NULL, {NULL} }
, { "floppy_disk", "\u1f4bE", NULL, {NULL} }
, { "flower_playing_cards", "\u1f3b4", NULL, {NULL} }
, { "flushed", "\u1f633", NULL, {NULL} }
, { "flying_saucer", "\u1f6f8", NULL, {NULL} }
, { "fog", "\u1f32B\ufe0f", NULL, {NULL} }
, { "foggy", "\u1f301", NULL, {NULL} }
, { "football", "\u1f3c8", NULL, {NULL} }
, { "footprints", "\u1f463", NULL, {NULL} }
, { "fork_and_knife", "\u1f374", NULL, {NULL} }
, { "fortune_cookie", "\u1f960", NULL, {NULL} }
, { "fountain", "\u26f2", NULL, {NULL} }
, { "four", "4\ufe0f\u20e3", NULL, {NULL} }
, { "four_leaf_clover", "\u1f340", NULL, {NULL} }
, { "fox_face", "\u1f98A", NULL, {NULL} }
, { "fr", "\u1f1eB\u1f1f7", NULL, {NULL} }
, { "frame_with_picture", "\u1f5bC\ufe0f", NULL, {NULL} }
, { "free", "\u1f193", NULL, {NULL} }
, { "fried_egg", "\u1f373", NULL, {NULL} }
, { "fried_shrimp", "\u1f364", NULL, {NULL} }
, { "fries", "\u1f35F", NULL, {NULL} }
, { "frog", "\u1f438", NULL, {NULL} }
, { "frowning", "\u1f626", NULL, {NULL} }
, { "fuelpump", "\u26fd", NULL, {NULL} }
, { "full_moon", "\u1f315", NULL, {NULL} }
, { "full_moon_with_face", "\u1f31D", NULL, {NULL} }
, { "funeral_urn", "\u26b1\ufe0f", NULL, {NULL} }
, { "game_die", "\u1f3b2", NULL, {NULL} }
, { "gb", "\u1f1eC\u1f1e7", NULL, {NULL} }
, { "gear", "\u2699\ufe0f", NULL, {NULL} }
, { "gem", "\u1f48E", NULL, {NULL} }
, { "gemini", "\u264a", NULL, {NULL} }
, { "genie", "\u1f9dE", NULL, {NULL} }
, { "ghost", "\u1f47B", NULL, {NULL} }
, { "gift", "\u1f381", NULL, {NULL} }
, { "gift_heart", "\u1f49D", NULL, {NULL} }
, { "giraffe_face", "\u1f992", NULL, {NULL} }
, { "girl", "\u1f467", NULL, {NULL} }
, { "glass_of_milk", "\u1f95B", NULL, {NULL} }
, { "globe_with_meridians", "\u1f310", NULL, {NULL} }
, { "gloves", "\u1f9e4", NULL, {NULL} }
, { "goal_net", "\u1f945", NULL, {NULL} }
, { "goat", "\u1f410", NULL, {NULL} }
, { "golf", "\u26f3", NULL, {NULL} }
, { "golfer", "\u1f3cC\ufe0f", NULL, {NULL} }
, { "gorilla", "\u1f98D", NULL, {NULL} }
, { "grapes", "\u1f347", NULL, {NULL} }
, { "green_apple", "\u1f34F", NULL, {NULL} }
, { "green_book", "\u1f4d7", NULL, {NULL} }
, { "green_heart", "\u1f49A", "<3", {NULL} }
, { "green_salad", "\u1f957", NULL, {NULL} }
, { "grey_exclamation", "\u2755", NULL, {NULL} }
, { "grey_question", "\u2754", NULL, {NULL} }
, { "grimacing", "\u1f62C", NULL, {NULL} }
, { "grin", "\u1f601", NULL, {NULL} }
, { "grinning", "\u1f600", ":D", {NULL} }
, { "grinning_face_with_one_large_and_one_small_eye", "\u1f92A", NULL, {NULL} }
, { "grinning_face_with_star_eyes", "\u1f929", NULL, {NULL} }
, { "guardsman", "\u1f482", NULL, {NULL} }
, { "guitar", "\u1f3b8", NULL, {NULL} }
, { "gun", "\u1f52B", NULL, {NULL} }
, { "haircut", "\u1f487", NULL, {NULL} }
, { "hamburger", "\u1f354", NULL, {NULL} }
, { "hammer", "\u1f528", NULL, {NULL} }
, { "hammer_and_pick", "\u2692\ufe0f", NULL, {NULL} }
, { "hammer_and_wrench", "\u1f6e0\ufe0f", NULL, {NULL} }
, { "hamster", "\u1f439", NULL, {NULL} }
, { "hand", "\u270b", NULL, {NULL} }
, { "hand_with_index_and_middle_fingers_crossed", "\u1f91E", NULL, {NULL} }
, { "handbag", "\u1f45C", NULL, {NULL} }
, { "handball", "\u1f93E", NULL, {NULL} }
, { "handshake", "\u1f91D", NULL, {NULL} }
, { "hankey", "\u1f4a9", NULL, {NULL} }
, { "hash", "#\ufe0f\u20e3", NULL, {NULL} }
, { "hatched_chick", "\u1f425", NULL, {NULL} }
, { "hatching_chick", "\u1f423", NULL, {NULL} }
, { "headphones", "\u1f3a7", NULL, {NULL} }
, { "hear_no_evil", "\u1f649", NULL, {NULL} }
, { "heart", "\u2764\ufe0f", "<3", {"<3", NULL} }
, { "heart_decoration", "\u1f49F", NULL, {NULL} }
, { "heart_eyes", "\u1f60D", NULL, {NULL} }
, { "heart_eyes_cat", "\u1f63B", NULL, {NULL} }
, { "heartbeat", "\u1f493", NULL, {NULL} }
, { "heartpulse", "\u1f497", NULL, {NULL} }
, { "hearts", "\u2665\ufe0f", NULL, {NULL} }
, { "heavy_check_mark", "\u2714\ufe0f", NULL, {NULL} }
, { "heavy_division_sign", "\u2797", NULL, {NULL} }
, { "heavy_dollar_sign", "\u1f4b2", NULL, {NULL} }
, { "heavy_exclamation_mark", "\u2757", NULL, {NULL} }
, { "heavy_heart_exclamation_mark_ornament", "\u2763\ufe0f", NULL, {NULL} }
, { "heavy_minus_sign", "\u2796", NULL, {NULL} }
, { "heavy_multiplication_x", "\u2716\ufe0f", NULL, {NULL} }
, { "heavy_plus_sign", "\u2795", NULL, {NULL} }
, { "hedgehog", "\u1f994", NULL, {NULL} }
, { "helicopter", "\u1f681", NULL, {NULL} }
, { "helmet_with_white_cross", "\u26d1\ufe0f", NULL, {NULL} }
, { "herb", "\u1f33F", NULL, {NULL} }
, { "hibiscus", "\u1f33A", NULL, {NULL} }
, { "high_brightness", "\u1f506", NULL, {NULL} }
, { "high_heel", "\u1f460", NULL, {NULL} }
, { "hocho", "\u1f52A", NULL, {NULL} }
, { "hole", "\u1f573\ufe0f", NULL, {NULL} }
, { "honey_pot", "\u1f36F", NULL, {NULL} }
, { "honeybee", "\u1f41D", NULL, {NULL} }
, { "horse", "\u1f434", NULL, {NULL} }
, { "horse_racing", "\u1f3c7", NULL, {NULL} }
, { "hospital", "\u1f3e5", NULL, {NULL} }
, { "hot_pepper", "\u1f336\ufe0f", NULL, {NULL} }
, { "hotdog", "\u1f32D", NULL, {NULL} }
, { "hotel", "\u1f3e8", NULL, {NULL} }
, { "hotsprings", "\u2668\ufe0f", NULL, {NULL} }
, { "hourglass", "\u231b", NULL, {NULL} }
, { "hourglass_flowing_sand", "\u23f3", NULL, {NULL} }
, { "house", "\u1f3e0", NULL, {NULL} }
, { "house_buildings", "\u1f3d8\ufe0f", NULL, {NULL} }
, { "house_with_garden", "\u1f3e1", NULL, {NULL} }
, { "hugging_face", "\u1f917", NULL, {NULL} }
, { "hushed", "\u1f62F", NULL, {NULL} }
, { "i_love_you_hand_sign", "\u1f91F", NULL, {NULL} }
, { "ice_cream", "\u1f368", NULL, {NULL} }
, { "ice_hockey_stick_and_puck", "\u1f3d2", NULL, {NULL} }
, { "ice_skate", "\u26f8\ufe0f", NULL, {NULL} }
, { "icecream", "\u1f366", NULL, {NULL} }
, { "id", "\u1f194", NULL, {NULL} }
, { "ideograph_advantage", "\u1f250", NULL, {NULL} }
, { "imp", "\u1f47F", NULL, {NULL} }
, { "inbox_tray", "\u1f4e5", NULL, {NULL} }
, { "incoming_envelope", "\u1f4e8", NULL, {NULL} }
, { "information_desk_person", "\u1f481", NULL, {NULL} }
, { "information_source", "\u2139\ufe0f", NULL, {NULL} }
, { "innocent", "\u1f607", NULL, {NULL} }
, { "interrobang", "\u2049\ufe0f", NULL, {NULL} }
, { "iphone", "\u1f4f1", NULL, {NULL} }
, { "it", "\u1f1eE\u1f1f9", NULL, {NULL} }
, { "izakaya_lantern", "\u1f3eE", NULL, {NULL} }
, { "jack_o_lantern", "\u1f383", NULL, {NULL} }
, { "japan", "\u1f5fE", NULL, {NULL} }
, { "japanese_castle", "\u1f3eF", NULL, {NULL} }
, { "japanese_goblin", "\u1f47A", NULL, {NULL} }
, { "japanese_ogre", "\u1f479", NULL, {NULL} }
, { "jeans", "\u1f456", NULL, {NULL} }
, { "joy", "\u1f602", NULL, {NULL} }
, { "joy_cat", "\u1f639", NULL, {NULL} }
, { "joystick", "\u1f579\ufe0f", NULL, {NULL} }
, { "jp", "\u1f1eF\u1f1f5", NULL, {NULL} }
, { "juggling", "\u1f939", NULL, {NULL} }
, { "kaaba", "\u1f54B", NULL, {NULL} }
, { "key", "\u1f511", NULL, {NULL} }
, { "keyboard", "\u2328\ufe0f", NULL, {NULL} }
, { "keycap_star", "*\ufe0f\u20e3", NULL, {NULL} }
, { "keycap_ten", "\u1f51F", NULL, {NULL} }
, { "kimono", "\u1f458", NULL, {NULL} }
, { "kiss", "\u1f48B", NULL, {NULL} }
, { "kissing", "\u1f617", NULL, {NULL} }
, { "kissing_cat", "\u1f63D", NULL, {NULL} }
, { "kissing_closed_eyes", "\u1f61A", NULL, {NULL} }
, { "kissing_heart", "\u1f618", NULL, {":*", ":-*", NULL} }
, { "kissing_smiling_eyes", "\u1f619", NULL, {NULL} }
, { "kiwifruit", "\u1f95D", NULL, {NULL} }
, { "knife", "\u1f52A", NULL, {NULL} }
, { "knife_fork_plate", "\u1f37D\ufe0f", NULL, {NULL} }
, { "koala", "\u1f428", NULL, {NULL} }
, { "koko", "\u1f201", NULL, {NULL} }
, { "kr", "\u1f1f0\u1f1f7", NULL, {NULL} }
, { "label", "\u1f3f7\ufe0f", NULL, {NULL} }
, { "lantern", "\u1f3eE", NULL, {NULL} }
, { "large_blue_circle", "\u1f535", NULL, {NULL} }
, { "large_blue_diamond", "\u1f537", NULL, {NULL} }
, { "large_orange_diamond", "\u1f536", NULL, {NULL} }
, { "last_quarter_moon", "\u1f317", NULL, {NULL} }
, { "last_quarter_moon_with_face", "\u1f31C", NULL, {NULL} }
, { "latin_cross", "\u271d\ufe0f", NULL, {NULL} }
, { "laughing", "\u1f606", NULL, {":>", ":->", NULL} }
, { "leaves", "\u1f343", NULL, {NULL} }
, { "ledger", "\u1f4d2", NULL, {NULL} }
, { "left-facing_fist", "\u1f91B", NULL, {NULL} }
, { "left_luggage", "\u1f6c5", NULL, {NULL} }
, { "left_right_arrow", "\u2194\ufe0f", NULL, {NULL} }
, { "left_speech_bubble", "\u1f5e8\ufe0f", NULL, {NULL} }
, { "leftwards_arrow_with_hook", "\u21a9\ufe0f", NULL, {NULL} }
, { "lemon", "\u1f34B", NULL, {NULL} }
, { "leo", "\u264c", NULL, {NULL} }
, { "leopard", "\u1f406", NULL, {NULL} }
, { "level_slider", "\u1f39A\ufe0f", NULL, {NULL} }
, { "libra", "\u264e", NULL, {NULL} }
, { "light_rail", "\u1f688", NULL, {NULL} }
, { "lightning", "\u1f329\ufe0f", NULL, {NULL} }
, { "lightning_cloud", "\u1f329\ufe0f", NULL, {NULL} }
, { "link", "\u1f517", NULL, {NULL} }
, { "linked_paperclips", "\u1f587\ufe0f", NULL, {NULL} }
, { "lion_face", "\u1f981", NULL, {NULL} }
, { "lips", "\u1f444", NULL, {NULL} }
, { "lipstick", "\u1f484", NULL, {NULL} }
, { "lizard", "\u1f98E", NULL, {NULL} }
, { "lock", "\u1f512", NULL, {NULL} }
, { "lock_with_ink_pen", "\u1f50F", NULL, {NULL} }
, { "lollipop", "\u1f36D", NULL, {NULL} }
, { "loop", "\u27bf", NULL, {NULL} }
, { "loud_sound", "\u1f50A", NULL, {NULL} }
, { "loudspeaker", "\u1f4e2", NULL, {NULL} }
, { "love_hotel", "\u1f3e9", NULL, {NULL} }
, { "love_letter", "\u1f48C", NULL, {NULL} }
, { "low_brightness", "\u1f505", NULL, {NULL} }
, { "lower_left_ballpoint_pen", "\u1f58A\ufe0f", NULL, {NULL} }
, { "lower_left_crayon", "\u1f58D\ufe0f", NULL, {NULL} }
, { "lower_left_fountain_pen", "\u1f58B\ufe0f", NULL, {NULL} }
, { "lower_left_paintbrush", "\u1f58C\ufe0f", NULL, {NULL} }
, { "lying_face", "\u1f925", NULL, {NULL} }
, { "m", "\u24c2\ufe0f", NULL, {NULL} }
, { "mag", "\u1f50D", NULL, {NULL} }
, { "mag_right", "\u1f50E", NULL, {NULL} }
, { "mage", "\u1f9d9", NULL, {NULL} }
, { "mahjong", "\u1f004", NULL, {NULL} }
, { "mailbox", "\u1f4eB", NULL, {NULL} }
, { "mailbox_closed", "\u1f4eA", NULL, {NULL} }
, { "mailbox_with_mail", "\u1f4eC", NULL, {NULL} }
, { "mailbox_with_no_mail", "\u1f4eD", NULL, {NULL} }
, { "male-artist", "\u1f468\u200d\u1f3a8", NULL, {NULL} }
, { "male-astronaut", "\u1f468\u200d\u1f680", NULL, {NULL} }
, { "male-construction-worker", "\u1f477\u200d\u2642\ufe0f", NULL, {NULL} }
, { "male-cook", "\u1f468\u200d\u1f373", NULL, {NULL} }
, { "male-detective", "\u1f575\ufe0f\u200d\u2642\ufe0f", NULL, {NULL} }
, { "male-doctor", "\u1f468\u200d\u2695\ufe0f", NULL, {NULL} }
, { "male-factory-worker", "\u1f468\u200d\u1f3eD", NULL, {NULL} }
, { "male-farmer", "\u1f468\u200d\u1f33E", NULL, {NULL} }
, { "male-firefighter", "\u1f468\u200d\u1f692", NULL, {NULL} }
, { "male-guard", "\u1f482\u200d\u2642\ufe0f", NULL, {NULL} }
, { "male-judge", "\u1f468\u200d\u2696\ufe0f", NULL, {NULL} }
, { "male-mechanic", "\u1f468\u200d\u1f527", NULL, {NULL} }
, { "male-office-worker", "\u1f468\u200d\u1f4bC", NULL, {NULL} }
, { "male-pilot", "\u1f468\u200d\u2708\ufe0f", NULL, {NULL} }
, { "male-police-officer", "\u1f46E\u200d\u2642\ufe0f", NULL, {NULL} }
, { "male-scientist", "\u1f468\u200d\u1f52C", NULL, {NULL} }
, { "male-singer", "\u1f468\u200d\u1f3a4", NULL, {NULL} }
, { "male-student", "\u1f468\u200d\u1f393", NULL, {NULL} }
, { "male-teacher", "\u1f468\u200d\u1f3eB", NULL, {NULL} }
, { "male-technologist", "\u1f468\u200d\u1f4bB", NULL, {NULL} }
, { "male_elf", "\u1f9dD\u200d\u2642\ufe0f", NULL, {NULL} }
, { "male_fairy", "\u1f9dA\u200d\u2642\ufe0f", NULL, {NULL} }
, { "male_genie", "\u1f9dE\u200d\u2642\ufe0f", NULL, {NULL} }
, { "male_mage", "\u1f9d9\u200d\u2642\ufe0f", NULL, {NULL} }
, { "male_sign", "\u2642\ufe0f", NULL, {NULL} }
, { "male_vampire", "\u1f9dB\u200d\u2642\ufe0f", NULL, {NULL} }
, { "male_zombie", "\u1f9dF\u200d\u2642\ufe0f", NULL, {NULL} }
, { "man", "\u1f468", NULL, {NULL} }
, { "man-biking", "\u1f6b4\u200d\u2642\ufe0f", NULL, {NULL} }
, { "man-bouncing-ball", "\u26f9\ufe0f\u200d\u2642\ufe0f", NULL, {NULL} }
, { "man-bowing", "\u1f647\u200d\u2642\ufe0f", NULL, {NULL} }
, { "man-boy", "\u1f468\u200d\u1f466", NULL, {NULL} }
, { "man-boy-boy", "\u1f468\u200d\u1f466\u200d\u1f466", NULL, {NULL} }
, { "man-cartwheeling", "\u1f938\u200d\u2642\ufe0f", NULL, {NULL} }
, { "man-facepalming", "\u1f926\u200d\u2642\ufe0f", NULL, {NULL} }
, { "man-frowning", "\u1f64D\u200d\u2642\ufe0f", NULL, {NULL} }
, { "man-gesturing-no", "\u1f645\u200d\u2642\ufe0f", NULL, {NULL} }
, { "man-gesturing-ok", "\u1f646\u200d\u2642\ufe0f", NULL, {NULL} }
, { "man-getting-haircut", "\u1f487\u200d\u2642\ufe0f", NULL, {NULL} }
, { "man-getting-massage", "\u1f486\u200d\u2642\ufe0f", NULL, {NULL} }
, { "man-girl", "\u1f468\u200d\u1f467", NULL, {NULL} }
, { "man-girl-boy", "\u1f468\u200d\u1f467\u200d\u1f466", NULL, {NULL} }
, { "man-girl-girl", "\u1f468\u200d\u1f467\u200d\u1f467", NULL, {NULL} }
, { "man-golfing", "\u1f3cC\ufe0f\u200d\u2642\ufe0f", NULL, {NULL} }
, { "man-heart-man", "\u1f468\u200d\u2764\ufe0f\u200d\u1f468", NULL, {NULL} }
, { "man-juggling", "\u1f939\u200d\u2642\ufe0f", NULL, {NULL} }
, { "man-kiss-man", "\u1f468\u200d\u2764\ufe0f\u200d\u1f48B\u200d\u1f468", NULL, {NULL} }
, { "man-lifting-weights", "\u1f3cB\ufe0f\u200d\u2642\ufe0f", NULL, {NULL} }
, { "man-man-boy", "\u1f468\u200d\u1f468\u200d\u1f466", NULL, {NULL} }
, { "man-man-boy-boy", "\u1f468\u200d\u1f468\u200d\u1f466\u200d\u1f466", NULL, {NULL} }
, { "man-man-girl", "\u1f468\u200d\u1f468\u200d\u1f467", NULL, {NULL} }
, { "man-man-girl-boy", "\u1f468\u200d\u1f468\u200d\u1f467\u200d\u1f466", NULL, {NULL} }
, { "man-man-girl-girl", "\u1f468\u200d\u1f468\u200d\u1f467\u200d\u1f467", NULL, {NULL} }
, { "man-mountain-biking", "\u1f6b5\u200d\u2642\ufe0f", NULL, {NULL} }
, { "man-playing-handball", "\u1f93E\u200d\u2642\ufe0f", NULL, {NULL} }
, { "man-playing-water-polo", "\u1f93D\u200d\u2642\ufe0f", NULL, {NULL} }
, { "man-pouting", "\u1f64E\u200d\u2642\ufe0f", NULL, {NULL} }
, { "man-raising-hand", "\u1f64B\u200d\u2642\ufe0f", NULL, {NULL} }
, { "man-rowing-boat", "\u1f6a3\u200d\u2642\ufe0f", NULL, {NULL} }
, { "man-running", "\u1f3c3\u200d\u2642\ufe0f", NULL, {NULL} }
, { "man-shrugging", "\u1f937\u200d\u2642\ufe0f", NULL, {NULL} }
, { "man-surfing", "\u1f3c4\u200d\u2642\ufe0f", NULL, {NULL} }
, { "man-swimming", "\u1f3cA\u200d\u2642\ufe0f", NULL, {NULL} }
, { "man-tipping-hand", "\u1f481\u200d\u2642\ufe0f", NULL, {NULL} }
, { "man-walking", "\u1f6b6\u200d\u2642\ufe0f", NULL, {NULL} }
, { "man-wearing-turban", "\u1f473\u200d\u2642\ufe0f", NULL, {NULL} }
, { "man-with-bunny-ears-partying", "\u1f46F\u200d\u2642\ufe0f", NULL, {NULL} }
, { "man-woman-boy", "\u1f468\u200d\u1f469\u200d\u1f466", NULL, {NULL} }
, { "man-woman-boy", "\u1f46A", NULL, {NULL} }
, { "man-woman-boy-boy", "\u1f468\u200d\u1f469\u200d\u1f466\u200d\u1f466", NULL, {NULL} }
, { "man-woman-girl", "\u1f468\u200d\u1f469\u200d\u1f467", NULL, {NULL} }
, { "man-woman-girl-boy", "\u1f468\u200d\u1f469\u200d\u1f467\u200d\u1f466", NULL, {NULL} }
, { "man-woman-girl-girl", "\u1f468\u200d\u1f469\u200d\u1f467\u200d\u1f467", NULL, {NULL} }
, { "man-wrestling", "\u1f93C\u200d\u2642\ufe0f", NULL, {NULL} }
, { "man_and_woman_holding_hands", "\u1f46B", NULL, {NULL} }
, { "man_climbing", "\u1f9d7\u200d\u2642\ufe0f", NULL, {NULL} }
, { "man_dancing", "\u1f57A", NULL, {NULL} }
, { "man_in_business_suit_levitating", "\u1f574\ufe0f", NULL, {NULL} }
, { "man_in_lotus_position", "\u1f9d8\u200d\u2642\ufe0f", NULL, {NULL} }
, { "man_in_steamy_room", "\u1f9d6\u200d\u2642\ufe0f", NULL, {NULL} }
, { "man_in_tuxedo", "\u1f935", NULL, {NULL} }
, { "man_with_gua_pi_mao", "\u1f472", NULL, {NULL} }
, { "man_with_turban", "\u1f473", NULL, {NULL} }
, { "mans_shoe", "\u1f45E", NULL, {NULL} }
, { "mantelpiece_clock", "\u1f570\ufe0f", NULL, {NULL} }
, { "maple_leaf", "\u1f341", NULL, {NULL} }
, { "martial_arts_uniform", "\u1f94B", NULL, {NULL} }
, { "mask", "\u1f637", NULL, {NULL} }
, { "massage", "\u1f486", NULL, {NULL} }
, { "meat_on_bone", "\u1f356", NULL, {NULL} }
, { "medal", "\u1f396\ufe0f", NULL, {NULL} }
, { "medical_symbol", "\u2695\ufe0f", NULL, {NULL} }
, { "mega", "\u1f4e3", NULL, {NULL} }
, { "melon", "\u1f348", NULL, {NULL} }
, { "memo", "\u1f4dD", NULL, {NULL} }
, { "menorah_with_nine_branches", "\u1f54E", NULL, {NULL} }
, { "mens", "\u1f6b9", NULL, {NULL} }
, { "mermaid", "\u1f9dC\u200d\u2640\ufe0f", NULL, {NULL} }
, { "merman", "\u1f9dC\u200d\u2642\ufe0f", NULL, {NULL} }
, { "merperson", "\u1f9dC", NULL, {NULL} }
, { "metro", "\u1f687", NULL, {NULL} }
, { "microphone", "\u1f3a4", NULL, {NULL} }
, { "microscope", "\u1f52C", NULL, {NULL} }
, { "middle_finger", "\u1f595", NULL, {NULL} }
, { "milky_way", "\u1f30C", NULL, {NULL} }
, { "minibus", "\u1f690", NULL, {NULL} }
, { "minidisc", "\u1f4bD", NULL, {NULL} }
, { "mobile_phone_off", "\u1f4f4", NULL, {NULL} }
, { "money_mouth_face", "\u1f911", NULL, {NULL} }
, { "money_with_wings", "\u1f4b8", NULL, {NULL} }
, { "moneybag", "\u1f4b0", NULL, {NULL} }
, { "monkey", "\u1f412", NULL, {NULL} }
, { "monkey_face", "\u1f435", NULL, {":o)", NULL} }
, { "monorail", "\u1f69D", NULL, {NULL} }
, { "moon", "\u1f314", NULL, {NULL} }
, { "mortar_board", "\u1f393", NULL, {NULL} }
, { "mosque", "\u1f54C", NULL, {NULL} }
, { "mostly_sunny", "\u1f324\ufe0f", NULL, {NULL} }
, { "mother_christmas", "\u1f936", NULL, {NULL} }
, { "motor_boat", "\u1f6e5\ufe0f", NULL, {NULL} }
, { "motor_scooter", "\u1f6f5", NULL, {NULL} }
, { "motorway", "\u1f6e3\ufe0f", NULL, {NULL} }
, { "mount_fuji", "\u1f5fB", NULL, {NULL} }
, { "mountain", "\u26f0\ufe0f", NULL, {NULL} }
, { "mountain_bicyclist", "\u1f6b5", NULL, {NULL} }
, { "mountain_cableway", "\u1f6a0", NULL, {NULL} }
, { "mountain_railway", "\u1f69E", NULL, {NULL} }
, { "mouse", "\u1f42D", NULL, {NULL} }
, { "mouse2", "\u1f401", NULL, {NULL} }
, { "movie_camera", "\u1f3a5", NULL, {NULL} }
, { "moyai", "\u1f5fF", NULL, {NULL} }
, { "mrs_claus", "\u1f936", NULL, {NULL} }
, { "muscle", "\u1f4aA", NULL, {NULL} }
, { "mushroom", "\u1f344", NULL, {NULL} }
, { "musical_keyboard", "\u1f3b9", NULL, {NULL} }
, { "musical_note", "\u1f3b5", NULL, {NULL} }
, { "musical_score", "\u1f3bC", NULL, {NULL} }
, { "mute", "\u1f507", NULL, {NULL} }
, { "nail_care", "\u1f485", NULL, {NULL} }
, { "name_badge", "\u1f4dB", NULL, {NULL} }
, { "national_park", "\u1f3dE\ufe0f", NULL, {NULL} }
, { "nauseated_face", "\u1f922", NULL, {NULL} }
, { "necktie", "\u1f454", NULL, {NULL} }
, { "negative_squared_cross_mark", "\u274e", NULL, {NULL} }
, { "nerd_face", "\u1f913", NULL, {NULL} }
, { "neutral_face", "\u1f610", NULL, {":|", ":-|", NULL} }
, { "new", "\u1f195", NULL, {NULL} }
, { "new_moon", "\u1f311", NULL, {NULL} }
, { "new_moon_with_face", "\u1f31A", NULL, {NULL} }
, { "newspaper", "\u1f4f0", NULL, {NULL} }
, { "ng", "\u1f196", NULL, {NULL} }
, { "night_with_stars", "\u1f303", NULL, {NULL} }
, { "nine", "9\ufe0f\u20e3", NULL, {NULL} }
, { "no_bell", "\u1f515", NULL, {NULL} }
, { "no_bicycles", "\u1f6b3", NULL, {NULL} }
, { "no_entry", "\u26d4", NULL, {NULL} }
, { "no_entry_sign", "\u1f6aB", NULL, {NULL} }
, { "no_good", "\u1f645", NULL, {NULL} }
, { "no_mobile_phones", "\u1f4f5", NULL, {NULL} }
, { "no_mouth", "\u1f636", NULL, {NULL} }
, { "no_pedestrians", "\u1f6b7", NULL, {NULL} }
, { "no_smoking", "\u1f6aD", NULL, {NULL} }
, { "non-potable_water", "\u1f6b1", NULL, {NULL} }
, { "nose", "\u1f443", NULL, {NULL} }
, { "notebook", "\u1f4d3", NULL, {NULL} }
, { "notebook_with_decorative_cover", "\u1f4d4", NULL, {NULL} }
, { "notes", "\u1f3b6", NULL, {NULL} }
, { "nut_and_bolt", "\u1f529", NULL, {NULL} }
, { "o", "\u2b55", NULL, {NULL} }
, { "o2", "\u1f17E\ufe0f", NULL, {NULL} }
, { "ocean", "\u1f30A", NULL, {NULL} }
, { "octagonal_sign", "\u1f6d1", NULL, {NULL} }
, { "octopus", "\u1f419", NULL, {NULL} }
, { "oden", "\u1f362", NULL, {NULL} }
, { "office", "\u1f3e2", NULL, {NULL} }
, { "oil_drum", "\u1f6e2\ufe0f", NULL, {NULL} }
, { "ok", "\u1f197", NULL, {NULL} }
, { "ok_hand", "\u1f44C", NULL, {NULL} }
, { "ok_woman", "\u1f646", NULL, {NULL} }
, { "old_key", "\u1f5dD\ufe0f", NULL, {NULL} }
, { "older_adult", "\u1f9d3", NULL, {NULL} }
, { "older_man", "\u1f474", NULL, {NULL} }
, { "older_woman", "\u1f475", NULL, {NULL} }
, { "om_symbol", "\u1f549\ufe0f", NULL, {NULL} }
, { "on", "\u1f51B", NULL, {NULL} }
, { "oncoming_automobile", "\u1f698", NULL, {NULL} }
, { "oncoming_bus", "\u1f68D", NULL, {NULL} }
, { "oncoming_police_car", "\u1f694", NULL, {NULL} }
, { "oncoming_taxi", "\u1f696", NULL, {NULL} }
, { "one", "1\ufe0f\u20e3", NULL, {NULL} }
, { "open_book", "\u1f4d6", NULL, {NULL} }
, { "open_file_folder", "\u1f4c2", NULL, {NULL} }
, { "open_hands", "\u1f450", NULL, {NULL} }
, { "open_mouth", "\u1f62E", NULL, {":o", ":-o", ":O", ":-O", NULL} }
, { "ophiuchus", "\u26ce", NULL, {NULL} }
, { "orange_book", "\u1f4d9", NULL, {NULL} }
, { "orange_heart", "\u1f9e1", NULL, {NULL} }
, { "orthodox_cross", "\u2626\ufe0f", NULL, {NULL} }
, { "outbox_tray", "\u1f4e4", NULL, {NULL} }
, { "owl", "\u1f989", NULL, {NULL} }
, { "ox", "\u1f402", NULL, {NULL} }
, { "package", "\u1f4e6", NULL, {NULL} }
, { "page_facing_up", "\u1f4c4", NULL, {NULL} }
, { "page_with_curl", "\u1f4c3", NULL, {NULL} }
, { "pager", "\u1f4dF", NULL, {NULL} }
, { "palm_tree", "\u1f334", NULL, {NULL} }
, { "palms_up_together", "\u1f932", NULL, {NULL} }
, { "pancakes", "\u1f95E", NULL, {NULL} }
, { "panda_face", "\u1f43C", NULL, {NULL} }
, { "paperclip", "\u1f4cE", NULL, {NULL} }
, { "parking", "\u1f17F\ufe0f", NULL, {NULL} }
, { "part_alternation_mark", "\u303d\ufe0f", NULL, {NULL} }
, { "partly_sunny", "\u26c5", NULL, {NULL} }
, { "partly_sunny_rain", "\u1f326\ufe0f", NULL, {NULL} }
, { "passenger_ship", "\u1f6f3\ufe0f", NULL, {NULL} }
, { "passport_control", "\u1f6c2", NULL, {NULL} }
, { "paw_prints", "\u1f43E", NULL, {NULL} }
, { "peace_symbol", "\u262e\ufe0f", NULL, {NULL} }
, { "peach", "\u1f351", NULL, {NULL} }
, { "peanuts", "\u1f95C", NULL, {NULL} }
, { "pear", "\u1f350", NULL, {NULL} }
, { "pencil", "\u1f4dD", NULL, {NULL} }
, { "pencil2", "\u270f\ufe0f", NULL, {NULL} }
, { "penguin", "\u1f427", NULL, {NULL} }
, { "pensive", "\u1f614", NULL, {NULL} }
, { "performing_arts", "\u1f3aD", NULL, {NULL} }
, { "persevere", "\u1f623", NULL, {NULL} }
, { "person_climbing", "\u1f9d7", NULL, {NULL} }
, { "person_doing_cartwheel", "\u1f938", NULL, {NULL} }
, { "person_frowning", "\u1f64D", NULL, {NULL} }
, { "person_in_lotus_position", "\u1f9d8", NULL, {NULL} }
, { "person_in_steamy_room", "\u1f9d6", NULL, {NULL} }
, { "person_with_ball", "\u26f9\ufe0f", NULL, {NULL} }
, { "person_with_blond_hair", "\u1f471", NULL, {NULL} }
, { "person_with_headscarf", "\u1f9d5", NULL, {NULL} }
, { "person_with_pouting_face", "\u1f64E", NULL, {NULL} }
, { "phone", "\u260e\ufe0f", NULL, {NULL} }
, { "pick", "\u26cf\ufe0f", NULL, {NULL} }
, { "pie", "\u1f967", NULL, {NULL} }
, { "pig", "\u1f437", NULL, {NULL} }
, { "pig2", "\u1f416", NULL, {NULL} }
, { "pig_nose", "\u1f43D", NULL, {NULL} }
, { "pill", "\u1f48A", NULL, {NULL} }
, { "pineapple", "\u1f34D", NULL, {NULL} }
, { "pisces", "\u2653", NULL, {NULL} }
, { "pizza", "\u1f355", NULL, {NULL} }
, { "place_of_worship", "\u1f6d0", NULL, {NULL} }
, { "point_down", "\u1f447", NULL, {NULL} }
, { "point_left", "\u1f448", NULL, {NULL} }
, { "point_right", "\u1f449", NULL, {NULL} }
, { "point_up", "\u261d\ufe0f", NULL, {NULL} }
, { "point_up_2", "\u1f446", NULL, {NULL} }
, { "police_car", "\u1f693", NULL, {NULL} }
, { "poodle", "\u1f429", NULL, {NULL} }
, { "poop", "\u1f4a9", NULL, {NULL} }
, { "popcorn", "\u1f37F", NULL, {NULL} }
, { "post_office", "\u1f3e3", NULL, {NULL} }
, { "postal_horn", "\u1f4eF", NULL, {NULL} }
, { "postbox", "\u1f4eE", NULL, {NULL} }
, { "potable_water", "\u1f6b0", NULL, {NULL} }
, { "potato", "\u1f954", NULL, {NULL} }
, { "pouch", "\u1f45D", NULL, {NULL} }
, { "poultry_leg", "\u1f357", NULL, {NULL} }
, { "pound", "\u1f4b7", NULL, {NULL} }
, { "pouting_cat", "\u1f63E", NULL, {NULL} }
, { "pray", "\u1f64F", NULL, {NULL} }
, { "prayer_beads", "\u1f4fF", NULL, {NULL} }
, { "pregnant_woman", "\u1f930", NULL, {NULL} }
, { "pretzel", "\u1f968", NULL, {NULL} }
, { "prince", "\u1f934", NULL, {NULL} }
, { "princess", "\u1f478", NULL, {NULL} }
, { "printer", "\u1f5a8\ufe0f", NULL, {NULL} }
, { "punch", "\u1f44A", NULL, {NULL} }
, { "purple_heart", "\u1f49C", "<3", {NULL} }
, { "purse", "\u1f45B", NULL, {NULL} }
, { "pushpin", "\u1f4cC", NULL, {NULL} }
, { "put_litter_in_its_place", "\u1f6aE", NULL, {NULL} }
, { "question", "\u2753", NULL, {NULL} }
, { "rabbit", "\u1f430", NULL, {NULL} }
, { "rabbit2", "\u1f407", NULL, {NULL} }
, { "racehorse", "\u1f40E", NULL, {NULL} }
, { "racing_car", "\u1f3cE\ufe0f", NULL, {NULL} }
, { "racing_motorcycle", "\u1f3cD\ufe0f", NULL, {NULL} }
, { "radio", "\u1f4fB", NULL, {NULL} }
, { "radio_button", "\u1f518", NULL, {NULL} }
, { "radioactive_sign", "\u2622\ufe0f", NULL, {NULL} }
, { "rage", "\u1f621", NULL, {NULL} }
, { "railway_car", "\u1f683", NULL, {NULL} }
, { "railway_track", "\u1f6e4\ufe0f", NULL, {NULL} }
, { "rain_cloud", "\u1f327\ufe0f", NULL, {NULL} }
, { "rainbow", "\u1f308", NULL, {NULL} }
, { "rainbow-flag", "\u1f3f3\ufe0f\u200d\u1f308", NULL, {NULL} }
, { "raised_back_of_hand", "\u1f91A", NULL, {NULL} }
, { "raised_hand", "\u270b", NULL, {NULL} }
, { "raised_hand_with_fingers_splayed", "\u1f590\ufe0f", NULL, {NULL} }
, { "raised_hands", "\u1f64C", NULL, {NULL} }
, { "raising_hand", "\u1f64B", NULL, {NULL} }
, { "ram", "\u1f40F", NULL, {NULL} }
, { "ramen", "\u1f35C", NULL, {NULL} }
, { "rat", "\u1f400", NULL, {NULL} }
, { "recycle", "\u267b\ufe0f", NULL, {NULL} }
, { "red_car", "\u1f697", NULL, {NULL} }
, { "red_circle", "\u1f534", NULL, {NULL} }
, { "registered", "\u00ae\ufe0f", NULL, {NULL} }
, { "relaxed", "\u263a\ufe0f", NULL, {NULL} }
, { "relieved", "\u1f60C", NULL, {NULL} }
, { "reminder_ribbon", "\u1f397\ufe0f", NULL, {NULL} }
, { "repeat", "\u1f501", NULL, {NULL} }
, { "repeat_one", "\u1f502", NULL, {NULL} }
, { "restroom", "\u1f6bB", NULL, {NULL} }
, { "reversed_hand_with_middle_finger_extended", "\u1f595", NULL, {NULL} }
, { "revolving_hearts", "\u1f49E", NULL, {NULL} }
, { "rewind", "\u23ea", NULL, {NULL} }
, { "rhinoceros", "\u1f98F", NULL, {NULL} }
, { "ribbon", "\u1f380", NULL, {NULL} }
, { "rice", "\u1f35A", NULL, {NULL} }
, { "rice_ball", "\u1f359", NULL, {NULL} }
, { "rice_cracker", "\u1f358", NULL, {NULL} }
, { "rice_scene", "\u1f391", NULL, {NULL} }
, { "right-facing_fist", "\u1f91C", NULL, {NULL} }
, { "right_anger_bubble", "\u1f5eF\ufe0f", NULL, {NULL} }
, { "ring", "\u1f48D", NULL, {NULL} }
, { "robot_face", "\u1f916", NULL, {NULL} }
, { "rocket", "\u1f680", NULL, {NULL} }
, { "rolled_up_newspaper", "\u1f5dE\ufe0f", NULL, {NULL} }
, { "roller_coaster", "\u1f3a2", NULL, {NULL} }
, { "rolling_on_the_floor_laughing", "\u1f923", NULL, {NULL} }
, { "rooster", "\u1f413", NULL, {NULL} }
, { "rose", "\u1f339", NULL, {NULL} }
, { "rosette", "\u1f3f5\ufe0f", NULL, {NULL} }
, { "rotating_light", "\u1f6a8", NULL, {NULL} }
, { "round_pushpin", "\u1f4cD", NULL, {NULL} }
, { "rowboat", "\u1f6a3", NULL, {NULL} }
, { "ru", "\u1f1f7\u1f1fA", NULL, {NULL} }
, { "rugby_football", "\u1f3c9", NULL, {NULL} }
, { "runner", "\u1f3c3", NULL, {NULL} }
, { "running", "\u1f3c3", NULL, {NULL} }
, { "running_shirt_with_sash", "\u1f3bD", NULL, {NULL} }
, { "sa", "\u1f202\ufe0f", NULL, {NULL} }
, { "sagittarius", "\u2650", NULL, {NULL} }
, { "sailboat", "\u26f5", NULL, {NULL} }
, { "sake", "\u1f376", NULL, {NULL} }
, { "sandal", "\u1f461", NULL, {NULL} }
, { "sandwich", "\u1f96A", NULL, {NULL} }
, { "santa", "\u1f385", NULL, {NULL} }
, { "satellite", "\u1f6f0\ufe0f", NULL, {NULL} }
, { "satellite_antenna", "\u1f4e1", NULL, {NULL} }
, { "satisfied", "\u1f606", NULL, {":>", ":->", NULL} }
, { "sauropod", "\u1f995", NULL, {NULL} }
, { "saxophone", "\u1f3b7", NULL, {NULL} }
, { "scales", "\u2696\ufe0f", NULL, {NULL} }
, { "scarf", "\u1f9e3", NULL, {NULL} }
, { "school", "\u1f3eB", NULL, {NULL} }
, { "school_satchel", "\u1f392", NULL, {NULL} }
, { "scissors", "\u2702\ufe0f", NULL, {NULL} }
, { "scooter", "\u1f6f4", NULL, {NULL} }
, { "scorpion", "\u1f982", NULL, {NULL} }
, { "scorpius", "\u264f", NULL, {NULL} }
, { "scream", "\u1f631", NULL, {NULL} }
, { "scream_cat", "\u1f640", NULL, {NULL} }
, { "scroll", "\u1f4dC", NULL, {NULL} }
, { "seat", "\u1f4bA", NULL, {NULL} }
, { "second_place_medal", "\u1f948", NULL, {NULL} }
, { "secret", "\u3299\ufe0f", NULL, {NULL} }
, { "see_no_evil", "\u1f648", NULL, {NULL} }
, { "seedling", "\u1f331", NULL, {NULL} }
, { "selfie", "\u1f933", NULL, {NULL} }
, { "serious_face_with_symbols_covering_mouth", "\u1f92C", NULL, {NULL} }
, { "seven", "7\ufe0f\u20e3", NULL, {NULL} }
, { "shallow_pan_of_food", "\u1f958", NULL, {NULL} }
, { "shamrock", "\u2618\ufe0f", NULL, {NULL} }
, { "shark", "\u1f988", NULL, {NULL} }
, { "shaved_ice", "\u1f367", NULL, {NULL} }
, { "sheep", "\u1f411", NULL, {NULL} }
, { "shell", "\u1f41A", NULL, {NULL} }
, { "shield", "\u1f6e1\ufe0f", NULL, {NULL} }
, { "shinto_shrine", "\u26e9\ufe0f", NULL, {NULL} }
, { "ship", "\u1f6a2", NULL, {NULL} }
, { "shirt", "\u1f455", NULL, {NULL} }
, { "shit", "\u1f4a9", NULL, {NULL} }
, { "shocked_face_with_exploding_head", "\u1f92F", NULL, {NULL} }
, { "shoe", "\u1f45E", NULL, {NULL} }
, { "shopping_bags", "\u1f6cD\ufe0f", NULL, {NULL} }
, { "shopping_trolley", "\u1f6d2", NULL, {NULL} }
, { "shower", "\u1f6bF", NULL, {NULL} }
, { "shrimp", "\u1f990", NULL, {NULL} }
, { "shrug", "\u1f937", NULL, {NULL} }
, { "shushing_face", "\u1f92B", NULL, {NULL} }
, { "sign_of_the_horns", "\u1f918", NULL, {NULL} }
, { "signal_strength", "\u1f4f6", NULL, {NULL} }
, { "six", "6\ufe0f\u20e3", NULL, {NULL} }
, { "six_pointed_star", "\u1f52F", NULL, {NULL} }
, { "ski", "\u1f3bF", NULL, {NULL} }
, { "skier", "\u26f7\ufe0f", NULL, {NULL} }
, { "skin-tone-2", "\u1f3fB", NULL, {NULL} }
, { "skin-tone-3", "\u1f3fC", NULL, {NULL} }
, { "skin-tone-4", "\u1f3fD", NULL, {NULL} }
, { "skin-tone-5", "\u1f3fE", NULL, {NULL} }
, { "skin-tone-6", "\u1f3fF", NULL, {NULL} }
, { "skull", "\u1f480", NULL, {NULL} }
, { "skull_and_crossbones", "\u2620\ufe0f", NULL, {NULL} }
, { "sled", "\u1f6f7", NULL, {NULL} }
, { "sleeping", "\u1f634", NULL, {NULL} }
, { "sleeping_accommodation", "\u1f6cC", NULL, {NULL} }
, { "sleepy", "\u1f62A", NULL, {NULL} }
, { "sleuth_or_spy", "\u1f575\ufe0f", NULL, {NULL} }
, { "slightly_frowning_face", "\u1f641", NULL, {NULL} }
, { "slightly_smiling_face", "\u1f642", NULL, {":)", "(:", ":-)", NULL} }
, { "slot_machine", "\u1f3b0", NULL, {NULL} }
, { "small_airplane", "\u1f6e9\ufe0f", NULL, {NULL} }
, { "small_blue_diamond", "\u1f539", NULL, {NULL} }
, { "small_orange_diamond", "\u1f538", NULL, {NULL} }
, { "small_red_triangle", "\u1f53A", NULL, {NULL} }
, { "small_red_triangle_down", "\u1f53B", NULL, {NULL} }
, { "smile", "\u1f604", ":)", {"C:", "c:", ":D", ":-D", NULL} }
, { "smile_cat", "\u1f638", NULL, {NULL} }
, { "smiley", "\u1f603", ":)", {"=)", "=-)", NULL} }
, { "smiley_cat", "\u1f63A", NULL, {NULL} }
, { "smiling_face_with_smiling_eyes_and_hand_covering_mouth", "\u1f92D", NULL, {NULL} }
, { "smiling_imp", "\u1f608", NULL, {NULL} }
, { "smirk", "\u1f60F", NULL, {NULL} }
, { "smirk_cat", "\u1f63C", NULL, {NULL} }
, { "smoking", "\u1f6aC", NULL, {NULL} }
, { "snail", "\u1f40C", NULL, {NULL} }
, { "snake", "\u1f40D", NULL, {NULL} }
, { "sneezing_face", "\u1f927", NULL, {NULL} }
, { "snow_capped_mountain", "\u1f3d4\ufe0f", NULL, {NULL} }
, { "snow_cloud", "\u1f328\ufe0f", NULL, {NULL} }
, { "snowboarder", "\u1f3c2", NULL, {NULL} }
, { "snowflake", "\u2744\ufe0f", NULL, {NULL} }
, { "snowman", "\u2603\ufe0f", NULL, {NULL} }
, { "snowman_without_snow", "\u26c4", NULL, {NULL} }
, { "sob", "\u1f62D", ":'(", {NULL} }
, { "soccer", "\u26bd", NULL, {NULL} }
, { "socks", "\u1f9e6", NULL, {NULL} }
, { "soon", "\u1f51C", NULL, {NULL} }
, { "sos", "\u1f198", NULL, {NULL} }
, { "sound", "\u1f509", NULL, {NULL} }
, { "space_invader", "\u1f47E", NULL, {NULL} }
, { "spades", "\u2660\ufe0f", NULL, {NULL} }
, { "spaghetti", "\u1f35D", NULL, {NULL} }
, { "sparkle", "\u2747\ufe0f", NULL, {NULL} }
, { "sparkler", "\u1f387", NULL, {NULL} }
, { "sparkles", "\u2728", NULL, {NULL} }
, { "sparkling_heart", "\u1f496", NULL, {NULL} }
, { "speak_no_evil", "\u1f64A", NULL, {NULL} }
, { "speaker", "\u1f508", NULL, {NULL} }
, { "speaking_head_in_silhouette", "\u1f5e3\ufe0f", NULL, {NULL} }
, { "speech_balloon", "\u1f4aC", NULL, {NULL} }
, { "speedboat", "\u1f6a4", NULL, {NULL} }
, { "spider", "\u1f577\ufe0f", NULL, {NULL} }
, { "spider_web", "\u1f578\ufe0f", NULL, {NULL} }
, { "spiral_calendar_pad", "\u1f5d3\ufe0f", NULL, {NULL} }
, { "spiral_note_pad", "\u1f5d2\ufe0f", NULL, {NULL} }
, { "spock-hand", "\u1f596", NULL, {NULL} }
, { "spoon", "\u1f944", NULL, {NULL} }
, { "sports_medal", "\u1f3c5", NULL, {NULL} }
, { "squid", "\u1f991", NULL, {NULL} }
, { "stadium", "\u1f3dF\ufe0f", NULL, {NULL} }
, { "staff_of_aesculapius", "\u2695\ufe0f", NULL, {NULL} }
, { "star", "\u2b50", NULL, {NULL} }
, { "star-struck", "\u1f929", NULL, {NULL} }
, { "star2", "\u1f31F", NULL, {NULL} }
, { "star_and_crescent", "\u262a\ufe0f", NULL, {NULL} }
, { "star_of_david", "\u2721\ufe0f", NULL, {NULL} }
, { "stars", "\u1f320", NULL, {NULL} }
, { "station", "\u1f689", NULL, {NULL} }
, { "statue_of_liberty", "\u1f5fD", NULL, {NULL} }
, { "steam_locomotive", "\u1f682", NULL, {NULL} }
, { "stew", "\u1f372", NULL, {NULL} }
, { "stopwatch", "\u23f1\ufe0f", NULL, {NULL} }
, { "straight_ruler", "\u1f4cF", NULL, {NULL} }
, { "strawberry", "\u1f353", NULL, {NULL} }
, { "stuck_out_tongue", "\u1f61B", ":p", {":p", ":-p", ":P", ":-P", ":b", ":-b", NULL} }
, { "stuck_out_tongue_closed_eyes", "\u1f61D", NULL, {NULL} }
, { "stuck_out_tongue_winking_eye", "\u1f61C", ";p", {";p", ";-p", ";b", ";-b", ";P", ";-P", NULL} }
, { "studio_microphone", "\u1f399\ufe0f", NULL, {NULL} }
, { "stuffed_flatbread", "\u1f959", NULL, {NULL} }
, { "sun_behind_cloud", "\u1f325\ufe0f", NULL, {NULL} }
, { "sun_behind_rain_cloud", "\u1f326\ufe0f", NULL, {NULL} }
, { "sun_small_cloud", "\u1f324\ufe0f", NULL, {NULL} }
, { "sun_with_face", "\u1f31E", NULL, {NULL} }
, { "sunflower", "\u1f33B", NULL, {NULL} }
, { "sunglasses", "\u1f60E", NULL, {"8)", NULL} }
, { "sunny", "\u2600\ufe0f", NULL, {NULL} }
, { "sunrise", "\u1f305", NULL, {NULL} }
, { "sunrise_over_mountains", "\u1f304", NULL, {NULL} }
, { "surfer", "\u1f3c4", NULL, {NULL} }
, { "sushi", "\u1f363", NULL, {NULL} }
, { "suspension_railway", "\u1f69F", NULL, {NULL} }
, { "sweat", "\u1f613", NULL, {NULL} }
, { "sweat_drops", "\u1f4a6", NULL, {NULL} }
, { "sweat_smile", "\u1f605", NULL, {NULL} }
, { "sweet_potato", "\u1f360", NULL, {NULL} }
, { "swimmer", "\u1f3cA", NULL, {NULL} }
, { "symbols", "\u1f523", NULL, {NULL} }
, { "synagogue", "\u1f54D", NULL, {NULL} }
, { "syringe", "\u1f489", NULL, {NULL} }
, { "t-rex", "\u1f996", NULL, {NULL} }
, { "table_tennis_paddle_and_ball", "\u1f3d3", NULL, {NULL} }
, { "taco", "\u1f32E", NULL, {NULL} }
, { "tada", "\u1f389", NULL, {NULL} }
, { "takeout_box", "\u1f961", NULL, {NULL} }
, { "tanabata_tree", "\u1f38B", NULL, {NULL} }
, { "tangerine", "\u1f34A", NULL, {NULL} }
, { "taurus", "\u2649", NULL, {NULL} }
, { "taxi", "\u1f695", NULL, {NULL} }
, { "tea", "\u1f375", NULL, {NULL} }
, { "telephone", "\u260e\ufe0f", NULL, {NULL} }
, { "telephone_receiver", "\u1f4dE", NULL, {NULL} }
, { "telescope", "\u1f52D", NULL, {NULL} }
, { "tennis", "\u1f3bE", NULL, {NULL} }
, { "tent", "\u26fa", NULL, {NULL} }
, { "the_horns", "\u1f918", NULL, {NULL} }
, { "thermometer", "\u1f321\ufe0f", NULL, {NULL} }
, { "thinking_face", "\u1f914", NULL, {NULL} }
, { "third_place_medal", "\u1f949", NULL, {NULL} }
, { "thought_balloon", "\u1f4aD", NULL, {NULL} }
, { "three", "3\ufe0f\u20e3", NULL, {NULL} }
, { "three_button_mouse", "\u1f5b1\ufe0f", NULL, {NULL} }
, { "thumbsdown", "\u1f44E", NULL, {NULL} }
, { "thumbsup", "\u1f44D", NULL, {NULL} }
, { "thunder_cloud_and_rain", "\u26c8\ufe0f", NULL, {NULL} }
, { "ticket", "\u1f3aB", NULL, {NULL} }
, { "tiger", "\u1f42F", NULL, {NULL} }
, { "tiger2", "\u1f405", NULL, {NULL} }
, { "timer_clock", "\u23f2\ufe0f", NULL, {NULL} }
, { "tired_face", "\u1f62B", NULL, {NULL} }
, { "tm", "\u2122\ufe0f", NULL, {NULL} }
, { "toilet", "\u1f6bD", NULL, {NULL} }
, { "tokyo_tower", "\u1f5fC", NULL, {NULL} }
, { "tomato", "\u1f345", NULL, {NULL} }
, { "tongue", "\u1f445", NULL, {NULL} }
, { "top", "\u1f51D", NULL, {NULL} }
, { "tophat", "\u1f3a9", NULL, {NULL} }
, { "tornado", "\u1f32A\ufe0f", NULL, {NULL} }
, { "tornado_cloud", "\u1f32A\ufe0f", NULL, {NULL} }
, { "trackball", "\u1f5b2\ufe0f", NULL, {NULL} }
, { "tractor", "\u1f69C", NULL, {NULL} }
, { "traffic_light", "\u1f6a5", NULL, {NULL} }
, { "train", "\u1f68B", NULL, {NULL} }
, { "train2", "\u1f686", NULL, {NULL} }
, { "tram", "\u1f68A", NULL, {NULL} }
, { "triangular_flag_on_post", "\u1f6a9", NULL, {NULL} }
, { "triangular_ruler", "\u1f4d0", NULL, {NULL} }
, { "trident", "\u1f531", NULL, {NULL} }
, { "triumph", "\u1f624", NULL, {NULL} }
, { "trolleybus", "\u1f68E", NULL, {NULL} }
, { "trophy", "\u1f3c6", NULL, {NULL} }
, { "tropical_drink", "\u1f379", NULL, {NULL} }
, { "tropical_fish", "\u1f420", NULL, {NULL} }
, { "truck", "\u1f69A", NULL, {NULL} }
, { "trumpet", "\u1f3bA", NULL, {NULL} }
, { "tshirt", "\u1f455", NULL, {NULL} }
, { "tulip", "\u1f337", NULL, {NULL} }
, { "tumbler_glass", "\u1f943", NULL, {NULL} }
, { "turkey", "\u1f983", NULL, {NULL} }
, { "turtle", "\u1f422", NULL, {NULL} }
, { "tv", "\u1f4fA", NULL, {NULL} }
, { "twisted_rightwards_arrows", "\u1f500", NULL, {NULL} }
, { "two", "2\ufe0f\u20e3", NULL, {NULL} }
, { "two_hearts", "\u1f495", NULL, {NULL} }
, { "two_men_holding_hands", "\u1f46C", NULL, {NULL} }
, { "two_women_holding_hands", "\u1f46D", NULL, {NULL} }
, { "u5272", "\u1f239", NULL, {NULL} }
, { "u5408", "\u1f234", NULL, {NULL} }
, { "u55b6", "\u1f23A", NULL, {NULL} }
, { "u6307", "\u1f22F", NULL, {NULL} }
, { "u6708", "\u1f237\ufe0f", NULL, {NULL} }
, { "u6709", "\u1f236", NULL, {NULL} }
, { "u6e80", "\u1f235", NULL, {NULL} }
, { "u7121", "\u1f21A", NULL, {NULL} }
, { "u7533", "\u1f238", NULL, {NULL} }
, { "u7981", "\u1f232", NULL, {NULL} }
, { "u7a7a", "\u1f233", NULL, {NULL} }
, { "uk", "\u1f1eC\u1f1e7", NULL, {NULL} }
, { "umbrella", "\u2602\ufe0f", NULL, {NULL} }
, { "umbrella_on_ground", "\u26f1\ufe0f", NULL, {NULL} }
, { "umbrella_with_rain_drops", "\u2614", NULL, {NULL} }
, { "unamused", "\u1f612", ":(", {NULL} }
, { "underage", "\u1f51E", NULL, {NULL} }
, { "unicorn_face", "\u1f984", NULL, {NULL} }
, { "unlock", "\u1f513", NULL, {NULL} }
, { "up", "\u1f199", NULL, {NULL} }
, { "upside_down_face", "\u1f643", NULL, {NULL} }
, { "us", "\u1f1fA\u1f1f8", NULL, {NULL} }
, { "v", "\u270c\ufe0f", NULL, {NULL} }
, { "vampire", "\u1f9dB", NULL, {NULL} }
, { "vertical_traffic_light", "\u1f6a6", NULL, {NULL} }
, { "vhs", "\u1f4fC", NULL, {NULL} }
, { "vibration_mode", "\u1f4f3", NULL, {NULL} }
, { "video_camera", "\u1f4f9", NULL, {NULL} }
, { "video_game", "\u1f3aE", NULL, {NULL} }
, { "violin", "\u1f3bB", NULL, {NULL} }
, { "virgo", "\u264d", NULL, {NULL} }
, { "volcano", "\u1f30B", NULL, {NULL} }
, { "volleyball", "\u1f3d0", NULL, {NULL} }
, { "vs", "\u1f19A", NULL, {NULL} }
, { "walking", "\u1f6b6", NULL, {NULL} }
, { "waning_crescent_moon", "\u1f318", NULL, {NULL} }
, { "waning_gibbous_moon", "\u1f316", NULL, {NULL} }
, { "warning", "\u26a0\ufe0f", NULL, {NULL} }
, { "wastebasket", "\u1f5d1\ufe0f", NULL, {NULL} }
, { "watch", "\u231a", NULL, {NULL} }
, { "water_buffalo", "\u1f403", NULL, {NULL} }
, { "water_polo", "\u1f93D", NULL, {NULL} }
, { "watermelon", "\u1f349", NULL, {NULL} }
, { "wave", "\u1f44B", NULL, {NULL} }
, { "waving_black_flag", "\u1f3f4", NULL, {NULL} }
, { "waving_white_flag", "\u1f3f3\ufe0f", NULL, {NULL} }
, { "wavy_dash", "\u3030\ufe0f", NULL, {NULL} }
, { "waxing_crescent_moon", "\u1f312", NULL, {NULL} }
, { "waxing_gibbous_moon", "\u1f314", NULL, {NULL} }
, { "wc", "\u1f6bE", NULL, {NULL} }
, { "weary", "\u1f629", NULL, {NULL} }
, { "wedding", "\u1f492", NULL, {NULL} }
, { "weight_lifter", "\u1f3cB\ufe0f", NULL, {NULL} }
, { "whale", "\u1f433", NULL, {NULL} }
, { "whale2", "\u1f40B", NULL, {NULL} }
, { "wheel_of_dharma", "\u2638\ufe0f", NULL, {NULL} }
, { "wheelchair", "\u267f", NULL, {NULL} }
, { "white_check_mark", "\u2705", NULL, {NULL} }
, { "white_circle", "\u26aa", NULL, {NULL} }
, { "white_flower", "\u1f4aE", NULL, {NULL} }
, { "white_frowning_face", "\u2639\ufe0f", NULL, {NULL} }
, { "white_large_square", "\u2b1c", NULL, {NULL} }
, { "white_medium_small_square", "\u25fd", NULL, {NULL} }
, { "white_medium_square", "\u25fb\ufe0f", NULL, {NULL} }
, { "white_small_square", "\u25ab\ufe0f", NULL, {NULL} }
, { "white_square_button", "\u1f533", NULL, {NULL} }
, { "wilted_flower", "\u1f940", NULL, {NULL} }
, { "wind_blowing_face", "\u1f32C\ufe0f", NULL, {NULL} }
, { "wind_chime", "\u1f390", NULL, {NULL} }
, { "wine_glass", "\u1f377", NULL, {NULL} }
, { "wink", "\u1f609", ";)", {";)", ";-)", NULL} }
, { "wolf", "\u1f43A", NULL, {NULL} }
, { "woman", "\u1f469", NULL, {NULL} }
, { "woman-biking", "\u1f6b4\u200d\u2640\ufe0f", NULL, {NULL} }
, { "woman-bouncing-ball", "\u26f9\ufe0f\u200d\u2640\ufe0f", NULL, {NULL} }
, { "woman-bowing", "\u1f647\u200d\u2640\ufe0f", NULL, {NULL} }
, { "woman-boy", "\u1f469\u200d\u1f466", NULL, {NULL} }
, { "woman-boy-boy", "\u1f469\u200d\u1f466\u200d\u1f466", NULL, {NULL} }
, { "woman-cartwheeling", "\u1f938\u200d\u2640\ufe0f", NULL, {NULL} }
, { "woman-facepalming", "\u1f926\u200d\u2640\ufe0f", NULL, {NULL} }
, { "woman-frowning", "\u1f64D\u200d\u2640\ufe0f", NULL, {NULL} }
, { "woman-gesturing-no", "\u1f645\u200d\u2640\ufe0f", NULL, {NULL} }
, { "woman-gesturing-ok", "\u1f646\u200d\u2640\ufe0f", NULL, {NULL} }
, { "woman-getting-haircut", "\u1f487\u200d\u2640\ufe0f", NULL, {NULL} }
, { "woman-getting-massage", "\u1f486\u200d\u2640\ufe0f", NULL, {NULL} }
, { "woman-girl", "\u1f469\u200d\u1f467", NULL, {NULL} }
, { "woman-girl-boy", "\u1f469\u200d\u1f467\u200d\u1f466", NULL, {NULL} }
, { "woman-girl-girl", "\u1f469\u200d\u1f467\u200d\u1f467", NULL, {NULL} }
, { "woman-golfing", "\u1f3cC\ufe0f\u200d\u2640\ufe0f", NULL, {NULL} }
, { "woman-heart-man", "\u1f469\u200d\u2764\ufe0f\u200d\u1f468", NULL, {NULL} }
, { "woman-heart-woman", "\u1f469\u200d\u2764\ufe0f\u200d\u1f469", NULL, {NULL} }
, { "woman-juggling", "\u1f939\u200d\u2640\ufe0f", NULL, {NULL} }
, { "woman-kiss-man", "\u1f469\u200d\u2764\ufe0f\u200d\u1f48B\u200d\u1f468", NULL, {NULL} }
, { "woman-kiss-woman", "\u1f469\u200d\u2764\ufe0f\u200d\u1f48B\u200d\u1f469", NULL, {NULL} }
, { "woman-lifting-weights", "\u1f3cB\ufe0f\u200d\u2640\ufe0f", NULL, {NULL} }
, { "woman-mountain-biking", "\u1f6b5\u200d\u2640\ufe0f", NULL, {NULL} }
, { "woman-playing-handball", "\u1f93E\u200d\u2640\ufe0f", NULL, {NULL} }
, { "woman-playing-water-polo", "\u1f93D\u200d\u2640\ufe0f", NULL, {NULL} }
, { "woman-pouting", "\u1f64E\u200d\u2640\ufe0f", NULL, {NULL} }
, { "woman-raising-hand", "\u1f64B\u200d\u2640\ufe0f", NULL, {NULL} }
, { "woman-rowing-boat", "\u1f6a3\u200d\u2640\ufe0f", NULL, {NULL} }
, { "woman-running", "\u1f3c3\u200d\u2640\ufe0f", NULL, {NULL} }
, { "woman-shrugging", "\u1f937\u200d\u2640\ufe0f", NULL, {NULL} }
, { "woman-surfing", "\u1f3c4\u200d\u2640\ufe0f", NULL, {NULL} }
, { "woman-swimming", "\u1f3cA\u200d\u2640\ufe0f", NULL, {NULL} }
, { "woman-tipping-hand", "\u1f481\u200d\u2640\ufe0f", NULL, {NULL} }
, { "woman-walking", "\u1f6b6\u200d\u2640\ufe0f", NULL, {NULL} }
, { "woman-wearing-turban", "\u1f473\u200d\u2640\ufe0f", NULL, {NULL} }
, { "woman-with-bunny-ears-partying", "\u1f46F\u200d\u2640\ufe0f", NULL, {NULL} }
, { "woman-woman-boy", "\u1f469\u200d\u1f469\u200d\u1f466", NULL, {NULL} }
, { "woman-woman-boy-boy", "\u1f469\u200d\u1f469\u200d\u1f466\u200d\u1f466", NULL, {NULL} }
, { "woman-woman-girl", "\u1f469\u200d\u1f469\u200d\u1f467", NULL, {NULL} }
, { "woman-woman-girl-boy", "\u1f469\u200d\u1f469\u200d\u1f467\u200d\u1f466", NULL, {NULL} }
, { "woman-woman-girl-girl", "\u1f469\u200d\u1f469\u200d\u1f467\u200d\u1f467", NULL, {NULL} }
, { "woman-wrestling", "\u1f93C\u200d\u2640\ufe0f", NULL, {NULL} }
, { "woman_climbing", "\u1f9d7\u200d\u2640\ufe0f", NULL, {NULL} }
, { "woman_in_lotus_position", "\u1f9d8\u200d\u2640\ufe0f", NULL, {NULL} }
, { "woman_in_steamy_room", "\u1f9d6\u200d\u2640\ufe0f", NULL, {NULL} }
, { "womans_clothes", "\u1f45A", NULL, {NULL} }
, { "womans_hat", "\u1f452", NULL, {NULL} }
, { "womens", "\u1f6bA", NULL, {NULL} }
, { "world_map", "\u1f5fA\ufe0f", NULL, {NULL} }
, { "worried", "\u1f61F", NULL, {NULL} }
, { "wrench", "\u1f527", NULL, {NULL} }
, { "wrestlers", "\u1f93C", NULL, {NULL} }
, { "writing_hand", "\u270d\ufe0f", NULL, {NULL} }
, { "x", "\u274c", NULL, {NULL} }
, { "yellow_heart", "\u1f49B", "<3", {NULL} }
, { "yen", "\u1f4b4", NULL, {NULL} }
, { "yin_yang", "\u262f\ufe0f", NULL, {NULL} }
, { "yum", "\u1f60B", NULL, {NULL} }
, { "zany_face", "\u1f92A", NULL, {NULL} }
, { "zap", "\u26a1", NULL, {NULL} }
, { "zebra_face", "\u1f993", NULL, {NULL} }
, { "zero", "0\ufe0f\u20e3", NULL, {NULL} }
, { "zipper_mouth_face", "\u1f910", NULL, {NULL} }
, { "zombie", "\u1f9dF", NULL, {NULL} }
, { "zzz", "\u1f4a4", NULL, {NULL} }
};

static struct t_slack_emoji_by_text slack_emoji_by_text[] =
{ { "(:", "\u1f642", "slightly_smiling_face", {"slightly_smiling_face", NULL} }
, { "):", "\u1f61E", "disappointed", {"disappointed", NULL} }
, { "8)", "\u1f60E", "sunglasses", {"sunglasses", NULL} }
, { ":'(", "\u1f622", "cry", {"cry", NULL} }
, { ":(", "\u1f61E", "disappointed", {"disappointed", NULL} }
, { ":)", "\u1f642", "slightly_smiling_face", {"slightly_smiling_face", NULL} }
, { ":*", "\u1f618", "kissing_heart", {"kissing_heart", NULL} }
, { ":-(", "\u1f61E", "disappointed", {"disappointed", NULL} }
, { ":-)", "\u1f642", "slightly_smiling_face", {"slightly_smiling_face", NULL} }
, { ":-*", "\u1f618", "kissing_heart", {"kissing_heart", NULL} }
, { ":-/", "\u1f615", "confused", {"confused", NULL} }
, { ":->", "\u1f606", "laughing", {"laughing", "satisfied", NULL} }
, { ":-D", "\u1f604", "smile", {"smile", NULL} }
, { ":-O", "\u1f62E", "open_mouth", {"open_mouth", NULL} }
, { ":-P", "\u1f61B", "stuck_out_tongue", {"stuck_out_tongue", NULL} }
, { ":-\\", "\u1f615", "confused", {"confused", NULL} }
, { ":-b", "\u1f61B", "stuck_out_tongue", {"stuck_out_tongue", NULL} }
, { ":-o", "\u1f62E", "open_mouth", {"open_mouth", NULL} }
, { ":-p", "\u1f61B", "stuck_out_tongue", {"stuck_out_tongue", NULL} }
, { ":-|", "\u1f610", "neutral_face", {"neutral_face", NULL} }
, { ":/", "\u1f615", "confused", {"confused", NULL} }
, { ":>", "\u1f606", "laughing", {"laughing", "satisfied", NULL} }
, { ":D", "\u1f604", "smile", {"smile", NULL} }
, { ":O", "\u1f62E", "open_mouth", {"open_mouth", NULL} }
, { ":P", "\u1f61B", "stuck_out_tongue", {"stuck_out_tongue", NULL} }
, { ":\\", "\u1f615", "confused", {"confused", NULL} }
, { ":b", "\u1f61B", "stuck_out_tongue", {"stuck_out_tongue", NULL} }
, { ":o", "\u1f62E", "open_mouth", {"open_mouth", NULL} }
, { ":o)", "\u1f435", "monkey_face", {"monkey_face", NULL} }
, { ":p", "\u1f61B", "stuck_out_tongue", {"stuck_out_tongue", NULL} }
, { ":|", "\u1f610", "neutral_face", {"neutral_face", NULL} }
, { ";)", "\u1f609", "wink", {"wink", NULL} }
, { ";-)", "\u1f609", "wink", {"wink", NULL} }
, { ";-P", "\u1f61C", "stuck_out_tongue_winking_eye", {"stuck_out_tongue_winking_eye", NULL} }
, { ";-b", "\u1f61C", "stuck_out_tongue_winking_eye", {"stuck_out_tongue_winking_eye", NULL} }
, { ";-p", "\u1f61C", "stuck_out_tongue_winking_eye", {"stuck_out_tongue_winking_eye", NULL} }
, { ";P", "\u1f61C", "stuck_out_tongue_winking_eye", {"stuck_out_tongue_winking_eye", NULL} }
, { ";b", "\u1f61C", "stuck_out_tongue_winking_eye", {"stuck_out_tongue_winking_eye", NULL} }
, { ";p", "\u1f61C", "stuck_out_tongue_winking_eye", {"stuck_out_tongue_winking_eye", NULL} }
, { "</3", "\u1f494", "broken_heart", {"broken_heart", NULL} }
, { "<3", "\u2764\ufe0f", "heart", {"heart", NULL} }
, { "=)", "\u1f603", "smiley", {"smiley", NULL} }
, { "=-)", "\u1f603", "smiley", {"smiley", NULL} }
, { ">:(", "\u1f620", "angry", {"angry", NULL} }
, { ">:-(", "\u1f620", "angry", {"angry", NULL} }
, { "C:", "\u1f604", "smile", {"smile", NULL} }
, { "D:", "\u1f627", "anguished", {"anguished", NULL} }
, { "c:", "\u1f604", "smile", {"smile", NULL} }
};
